@@ -87,7 +87,9 @@ public:
     /** Returns a list of times for this clip's markers */
     QList <GenTime> snapMarkers() const;
     QList <CommentedTime> commentedSnapMarkers() const;
+    /** Get the position of the fade in effect */
     int fadeIn() const;
+    /** Get the position of the fade out effect */
     int fadeOut() const;
     void setSelectedEffect(const int ix);
     void updateKeyframeEffect();
@@ -114,6 +116,9 @@ public:
     bool isAudioOnly() const;
     /** Called when clip start is resized, adjust keyframes values */
     bool checkEffectsKeyframesPos(const int previous, const int current, bool fromStart);
+    void insertKeyframe(QDomElement effect, int pos, int val);
+    void movedKeyframe(QDomElement effect, int oldpos, int newpos, double value);
+    void updateKeyframes(QDomElement effect);
 
 protected:
     //virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
@@ -168,7 +173,7 @@ private slots:
     void animate(qreal value);
     void slotSetStartThumb(QImage img);
     void slotSetEndThumb(QImage img);
-    void slotThumbReady(int frame, QPixmap pix);
+    void slotThumbReady(int frame, QImage img);
 
 public slots:
     void slotFetchThumbs();
