@@ -48,8 +48,10 @@ ClipManager::ClipManager(KdenliveDoc *doc) :
 
 ClipManager::~ClipManager()
 {
-    kDebug() << "\n\n 2222222222222222222222222  CLOSE CM 22222222222";
     qDeleteAll(m_clipList);
+    m_clipList.clear();
+    m_audioThumbsQueue.clear();
+    m_generatingAudioId.clear();
 }
 
 void ClipManager::clear()
@@ -170,7 +172,9 @@ void ClipManager::deleteClip(const QString &clipId)
                 // listen for file change
                 m_fileWatcher.removeFile(m_clipList.at(i)->fileURL().path());
             }
-            delete m_clipList.takeAt(i);
+            DocClipBase *clip = m_clipList.takeAt(i);
+            delete clip;
+            clip = NULL;
             break;
         }
     }
@@ -274,7 +278,7 @@ void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, co
                 prod.setAttribute("type", (int) IMAGE);
                 prod.setAttribute("in", 0);
                 prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
-            } else if (type->name() == "application/x-kdenlivetitle") {
+            } else if (type->is("application/x-kdenlivetitle")) {
                 // opening a title file
                 QDomDocument txtdoc("titledocument");
                 QFile txtfile(file.path());
@@ -335,6 +339,7 @@ void ClipManager::slotAddClipFile(const KUrl url, const QString group, const QSt
     m_doc->commandStack()->push(command);
 }
 
+
 void ClipManager::slotAddColorClipFile(const QString name, const QString color, QString duration, const QString group, const QString &groupId)
 {
     QDomDocument doc;
