@@ -38,11 +38,6 @@ static const int MARKERTAB = 5;
 static const int METATAB = 6;
 static const int ADVANCEDTAB = 7;
 
-static const int TYPE_JPEG = 0;
-static const int TYPE_PNG = 1;
-static const int TYPE_BMP = 2;
-static const int TYPE_GIF = 3;
-
 ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidget * parent) :
         QDialog(parent),
         m_clip(clip),
@@ -59,12 +54,27 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     m_view.clip_description->setText(m_clip->description());
     QMap <QString, QString> props = m_clip->properties();
 
+    m_view.clip_force_out->setHidden(true);
+    m_view.clip_out->setHidden(true);
+
     if (props.contains("force_aspect_ratio") && props.value("force_aspect_ratio").toDouble() > 0) {
         m_view.clip_force_ar->setChecked(true);
         m_view.clip_ar->setEnabled(true);
         m_view.clip_ar->setValue(props.value("force_aspect_ratio").toDouble());
     }
 
+    if (props.contains("force_fps") && props.value("force_fps").toDouble() > 0) {
+        m_view.clip_force_framerate->setChecked(true);
+        m_view.clip_framerate->setEnabled(true);
+        m_view.clip_framerate->setValue(props.value("force_fps").toDouble());
+    }
+
+    if (props.contains("force_progressive")) {
+        m_view.clip_force_progressive->setChecked(true);
+        m_view.clip_progressive->setEnabled(true);
+        m_view.clip_progressive->setValue(props.value("force_progressive").toInt());
+    }
+
     if (props.contains("threads") && props.value("threads").toInt() != 1) {
         m_view.clip_force_threads->setChecked(true);
         m_view.clip_threads->setEnabled(true);
@@ -102,6 +112,8 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     }
 
     connect(m_view.clip_force_ar, SIGNAL(toggled(bool)), m_view.clip_ar, SLOT(setEnabled(bool)));
+    connect(m_view.clip_force_framerate, SIGNAL(toggled(bool)), m_view.clip_framerate, SLOT(setEnabled(bool)));
+    connect(m_view.clip_force_progressive, SIGNAL(toggled(bool)), m_view.clip_progressive, SLOT(setEnabled(bool)));
     connect(m_view.clip_force_threads, SIGNAL(toggled(bool)), m_view.clip_threads, SLOT(setEnabled(bool)));
     connect(m_view.clip_force_vindex, SIGNAL(toggled(bool)), m_view.clip_vindex, SLOT(setEnabled(bool)));
     connect(m_view.clip_force_aindex, SIGNAL(toggled(bool)), m_view.clip_aindex, SLOT(setEnabled(bool)));
@@ -150,16 +162,28 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_view.tabWidget->removeTab(COLORTAB);
         m_view.tabWidget->removeTab(AUDIOTAB);
         m_view.tabWidget->removeTab(VIDEOTAB);
-        QStringList types;
-        types << "JPG" << "PNG" << "BMP" << "GIF";
-        m_view.image_type->addItems(types);
+
+        //WARNING: Keep in sync with slideshowclip.cpp
+        m_view.image_type->addItem("JPG (*.jpg)", "jpg");
+        m_view.image_type->addItem("JPEG (*.jpeg)", "jpeg");
+        m_view.image_type->addItem("PNG (*.png)", "png");
+        m_view.image_type->addItem("BMP (*.bmp)", "bmp");
+        m_view.image_type->addItem("GIF (*.gif)", "gif");
+        m_view.image_type->addItem("TGA (*.tga)", "tga");
+        m_view.image_type->addItem("TIFF (*.tiff)", "tiff");
+        m_view.image_type->addItem("Open EXR (*.exr)", "exr");
+
         m_view.slide_loop->setChecked(props.value("loop").toInt());
         m_view.slide_fade->setChecked(props.value("fade").toInt());
         m_view.luma_softness->setValue(props.value("softness").toInt());
         QString path = props.value("resource");
-        if (path.endsWith("png")) m_view.image_type->setCurrentIndex(TYPE_PNG);
-        else if (path.endsWith("bmp")) m_view.image_type->setCurrentIndex(TYPE_BMP);
-        else if (path.endsWith("gif")) m_view.image_type->setCurrentIndex(TYPE_GIF);
+        QString ext = path.section('.', -1);
+        for (int i = 0; i < m_view.image_type->count(); i++) {
+            if (m_view.image_type->itemData(i).toString() == ext) {
+                m_view.image_type->setCurrentIndex(i);
+                break;
+            }
+        }
         m_view.slide_duration->setText(tc.getTimecodeFromFrames(props.value("ttl").toInt()));
 
         m_view.slide_duration_format->addItem(i18n("hh:mm:ss::ff"));
@@ -197,13 +221,12 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.luma_file->addItem(KIcon(filePath), fname, filePath);
         }
 
-        slotEnableLuma(m_view.slide_fade->checkState());
-        slotEnableLumaFile(m_view.slide_luma->checkState());
-
         if (!lumaFile.isEmpty()) {
             m_view.slide_luma->setChecked(true);
             m_view.luma_file->setCurrentIndex(m_view.luma_file->findData(lumaFile));
         } else m_view.luma_file->setEnabled(false);
+        slotEnableLuma(m_view.slide_fade->checkState());
+        slotEnableLumaFile(m_view.slide_luma->checkState());
         connect(m_view.slide_fade, SIGNAL(stateChanged(int)), this, SLOT(slotEnableLuma(int)));
         connect(m_view.slide_luma, SIGNAL(stateChanged(int)), this, SLOT(slotEnableLumaFile(int)));
 
@@ -216,8 +239,10 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.clip_size->setText(props.value("frame_size"));
         if (props.contains("videocodec"))
             m_view.clip_vcodec->setText(props.value("videocodec"));
-        if (props.contains("fps"))
+        if (props.contains("fps")) {
             m_view.clip_fps->setText(props.value("fps"));
+            if (!m_view.clip_framerate->isEnabled()) m_view.clip_framerate->setValue(props.value("fps").toDouble());
+        }
         if (props.contains("aspect_ratio"))
             m_view.clip_ratio->setText(props.value("aspect_ratio"));
         int width = 180.0 * KdenliveSettings::project_display_ratio();
@@ -233,8 +258,13 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_view.clip_thumb->setHidden(true);
     }
 
-    KFileItem f(KFileItem::Unknown, KFileItem::Unknown, url, true);
-    m_view.clip_filesize->setText(KIO::convertSize(f.size()));
+    if (t != SLIDESHOW && t != COLOR) {
+        KFileItem f(KFileItem::Unknown, KFileItem::Unknown, url, true);
+        m_view.clip_filesize->setText(KIO::convertSize(f.size()));
+    } else {
+        m_view.clip_filesize->setHidden(true);
+        m_view.label_size->setHidden(true);
+    }
     m_view.clip_duration->setText(tc.getTimecode(m_clip->duration()));
     if (t != IMAGE && t != COLOR && t != TEXT) m_view.clip_duration->setReadOnly(true);
     else connect(m_view.clip_duration, SIGNAL(editingFinished()), this, SLOT(slotCheckMaxLength()));
@@ -256,6 +286,106 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     //adjustSize();
 }
 
+
+// Used for multiple clips editing
+ClipProperties::ClipProperties(QList <DocClipBase *>cliplist, Timecode tc, QMap <QString, QString> commonproperties, QWidget * parent) :
+        QDialog(parent),
+        m_clip(NULL),
+        m_tc(tc),
+        m_fps(0),
+        m_count(0),
+        m_clipNeedsRefresh(false),
+        m_clipNeedsReLoad(false)
+{
+    setFont(KGlobalSettings::toolBarFont());
+    m_view.setupUi(this);
+    QMap <QString, QString> props = cliplist.at(0)->properties();
+    m_old_props = commonproperties;
+
+    if (commonproperties.contains("force_aspect_ratio") && !commonproperties.value("force_aspect_ratio").isEmpty() && commonproperties.value("force_aspect_ratio").toDouble() > 0) {
+        m_view.clip_force_ar->setChecked(true);
+        m_view.clip_ar->setEnabled(true);
+        m_view.clip_ar->setValue(commonproperties.value("force_aspect_ratio").toDouble());
+    }
+
+    if (commonproperties.contains("force_fps") && !commonproperties.value("force_fps").isEmpty() && commonproperties.value("force_fps").toDouble() > 0) {
+        m_view.clip_force_framerate->setChecked(true);
+        m_view.clip_framerate->setEnabled(true);
+        m_view.clip_framerate->setValue(commonproperties.value("force_fps").toDouble());
+    }
+
+    if (commonproperties.contains("force_progressive") && !commonproperties.value("force_progressive").isEmpty()) {
+        m_view.clip_force_progressive->setChecked(true);
+        m_view.clip_progressive->setEnabled(true);
+        m_view.clip_progressive->setValue(commonproperties.value("force_progressive").toInt());
+    }
+
+    if (commonproperties.contains("threads") && !commonproperties.value("threads").isEmpty() && commonproperties.value("threads").toInt() != 1) {
+        m_view.clip_force_threads->setChecked(true);
+        m_view.clip_threads->setEnabled(true);
+        m_view.clip_threads->setValue(commonproperties.value("threads").toInt());
+    }
+
+    if (commonproperties.contains("video_index") && !commonproperties.value("video_index").isEmpty() && commonproperties.value("video_index").toInt() != 0) {
+        m_view.clip_force_vindex->setChecked(true);
+        m_view.clip_vindex->setEnabled(true);
+        m_view.clip_vindex->setValue(commonproperties.value("video_index").toInt());
+    }
+
+    if (commonproperties.contains("audio_index") && !commonproperties.value("audio_index").isEmpty() && commonproperties.value("audio_index").toInt() != 0) {
+        m_view.clip_force_aindex->setChecked(true);
+        m_view.clip_aindex->setEnabled(true);
+        m_view.clip_aindex->setValue(commonproperties.value("audio_index").toInt());
+    }
+
+    if (props.contains("audio_max")) {
+        m_view.clip_aindex->setMaximum(props.value("audio_max").toInt());
+    }
+
+    if (props.contains("video_max")) {
+        m_view.clip_vindex->setMaximum(props.value("video_max").toInt());
+    }
+
+    connect(m_view.clip_force_ar, SIGNAL(toggled(bool)), m_view.clip_ar, SLOT(setEnabled(bool)));
+    connect(m_view.clip_force_progressive, SIGNAL(toggled(bool)), m_view.clip_progressive, SLOT(setEnabled(bool)));
+    connect(m_view.clip_force_threads, SIGNAL(toggled(bool)), m_view.clip_threads, SLOT(setEnabled(bool)));
+    connect(m_view.clip_force_vindex, SIGNAL(toggled(bool)), m_view.clip_vindex, SLOT(setEnabled(bool)));
+    connect(m_view.clip_force_aindex, SIGNAL(toggled(bool)), m_view.clip_aindex, SLOT(setEnabled(bool)));
+    connect(m_view.clip_force_out, SIGNAL(toggled(bool)), m_view.clip_out, SLOT(setEnabled(bool)));
+
+    m_view.tabWidget->removeTab(METATAB);
+    m_view.tabWidget->removeTab(MARKERTAB);
+    m_view.tabWidget->removeTab(IMAGETAB);
+    m_view.tabWidget->removeTab(SLIDETAB);
+    m_view.tabWidget->removeTab(COLORTAB);
+    m_view.tabWidget->removeTab(AUDIOTAB);
+    m_view.tabWidget->removeTab(VIDEOTAB);
+
+    m_view.clip_path->setHidden(true);
+    m_view.label_path->setHidden(true);
+    m_view.label_description->setHidden(true);
+    m_view.label_size->setHidden(true);
+    m_view.clip_filesize->setHidden(true);
+    m_view.clip_filesize->setHidden(true);
+    m_view.clip_path->setHidden(true);
+    m_view.clip_description->setHidden(true);
+    m_view.clip_thumb->setHidden(true);
+    m_view.label_duration->setHidden(true);
+    m_view.clip_duration->setHidden(true);
+
+    if (commonproperties.contains("out")) {
+        if (commonproperties.value("out").toInt() > 0) {
+            m_view.clip_force_out->setChecked(true);
+            m_view.clip_out->setText(m_tc.getTimecodeFromFrames(commonproperties.value("out").toInt()));
+        } else m_view.clip_out->setText(KdenliveSettings::image_duration());
+    } else {
+        m_view.clip_force_out->setHidden(true);
+        m_view.clip_out->setHidden(true);
+    }
+}
+
+
+
 void ClipProperties::slotEnableLuma(int state)
 {
     bool enable = false;
@@ -332,111 +462,132 @@ const QString &ClipProperties::clipId() const
 QMap <QString, QString> ClipProperties::properties()
 {
     QMap <QString, QString> props;
-    CLIPTYPE t = m_clip->clipType();
-    QMap <QString, QString> old_props = m_clip->properties();
-
-    if (old_props.value("description") != m_view.clip_description->text())
-        props["description"] = m_view.clip_description->text();
+    CLIPTYPE t = UNKNOWN;
+    if (m_clip != NULL) {
+        t = m_clip->clipType();
+        m_old_props = m_clip->properties();
+    }
 
     double aspect = m_view.clip_ar->value();
     if (m_view.clip_force_ar->isChecked()) {
-        if (aspect != old_props.value("force_aspect_ratio").toDouble()) {
+        if (aspect != m_old_props.value("force_aspect_ratio").toDouble()) {
             props["force_aspect_ratio"] = QString::number(aspect);
             m_clipNeedsRefresh = true;
         }
-    } else if (old_props.contains("force_aspect_ratio")) {
+    } else if (m_old_props.contains("force_aspect_ratio")) {
         props["force_aspect_ratio"].clear();
         m_clipNeedsRefresh = true;
     }
 
+    double fps = m_view.clip_framerate->value();
+    if (m_view.clip_force_framerate->isChecked()) {
+        if (fps != m_old_props.value("force_fps").toDouble()) {
+            props["force_fps"] = QString::number(fps);
+            m_clipNeedsRefresh = true;
+        }
+    } else if (m_old_props.contains("force_fps")) {
+        props["force_fps"].clear();
+        m_clipNeedsRefresh = true;
+    }
+
+    int progressive = m_view.clip_progressive->value();
+    if (m_view.clip_force_progressive->isChecked()) {
+        if (progressive != m_old_props.value("force_progressive").toInt()) {
+            props["force_progressive"] = QString::number(progressive);
+        }
+    } else if (m_old_props.contains("force_progressive")) {
+        props["force_progressive"].clear();
+    }
+
     int threads = m_view.clip_threads->value();
     if (m_view.clip_force_threads->isChecked()) {
-        if (threads != old_props.value("threads").toInt()) {
+        if (threads != m_old_props.value("threads").toInt()) {
             props["threads"] = QString::number(threads);
         }
-    } else if (old_props.contains("threads")) {
+    } else if (m_old_props.contains("threads")) {
         props["threads"].clear();
     }
 
     int vindex = m_view.clip_vindex->value();
     if (m_view.clip_force_vindex->isChecked()) {
-        if (vindex != old_props.value("video_index").toInt()) {
+        if (vindex != m_old_props.value("video_index").toInt()) {
             props["video_index"] = QString::number(vindex);
         }
-    } else if (old_props.contains("video_index")) {
+    } else if (m_old_props.contains("video_index")) {
         props["video_index"].clear();
     }
 
     int aindex = m_view.clip_aindex->value();
     if (m_view.clip_force_aindex->isChecked()) {
-        if (aindex != old_props.value("audio_index").toInt()) {
+        if (aindex != m_old_props.value("audio_index").toInt()) {
             props["audio_index"] = QString::number(aindex);
         }
-    } else if (old_props.contains("audio_index")) {
+    } else if (m_old_props.contains("audio_index")) {
         props["audio_index"].clear();
     }
 
+    // If we adjust several clips, return now
+    if (m_clip == NULL) {
+        if (m_view.clip_out->isEnabled()) {
+            int duration = m_tc.getFrameCount(m_view.clip_out->text());
+            if (duration != m_old_props.value("out").toInt()) {
+                props["out"] = QString::number(duration - 1);
+            }
+        }
+        return props;
+    }
+
+    if (m_old_props.value("description") != m_view.clip_description->text())
+        props["description"] = m_view.clip_description->text();
+
     if (t == COLOR) {
         QString new_color = m_view.clip_color->color().name();
-        if (new_color != QString('#' + old_props.value("colour").right(8).left(6))) {
+        if (new_color != QString('#' + m_old_props.value("colour").right(8).left(6))) {
             m_clipNeedsRefresh = true;
             props["colour"] = "0x" + new_color.right(6) + "ff";
         }
         int duration = m_tc.getFrameCount(m_view.clip_duration->text());
         if (duration != m_clip->duration().frames(m_fps)) {
-            props["out"] = QString::number(duration);
+            props["out"] = QString::number(duration - 1);
         }
     } else if (t == IMAGE) {
-        if ((int) m_view.image_transparency->isChecked() != old_props.value("transparency").toInt()) {
+        if ((int) m_view.image_transparency->isChecked() != m_old_props.value("transparency").toInt()) {
             props["transparency"] = QString::number((int)m_view.image_transparency->isChecked());
             //m_clipNeedsRefresh = true;
         }
         int duration = m_tc.getFrameCount(m_view.clip_duration->text());
         if (duration != m_clip->duration().frames(m_fps)) {
-            props["out"] = QString::number(duration);
+            props["out"] = QString::number(duration - 1);
         }
     } else if (t == SLIDESHOW) {
         QString value = QString::number((int) m_view.slide_loop->isChecked());
-        if (old_props.value("loop") != value) props["loop"] = value;
+        if (m_old_props.value("loop") != value) props["loop"] = value;
         value = QString::number((int) m_view.slide_fade->isChecked());
-        if (old_props.value("fade") != value) props["fade"] = value;
+        if (m_old_props.value("fade") != value) props["fade"] = value;
         value = QString::number((int) m_view.luma_softness->value());
-        if (old_props.value("softness") != value) props["softness"] = value;
+        if (m_old_props.value("softness") != value) props["softness"] = value;
 
-        QString extension;
-        switch (m_view.image_type->currentIndex()) {
-        case TYPE_PNG:
-            extension = "/.all.png";
-            break;
-        case TYPE_BMP:
-            extension = "/.all.bmp";
-            break;
-        case TYPE_GIF:
-            extension = "/.all.gif";
-            break;
-        default:
-            extension = "/.all.jpg";
-            break;
-        }
+        QString extension = "/.all." + m_view.image_type->itemData(m_view.image_type->currentIndex()).toString();
         QString new_path = m_view.clip_path->text() + extension;
-        if (new_path != old_props.value("resource")) {
+        if (new_path != m_old_props.value("resource")) {
             m_clipNeedsReLoad = true;
             props["resource"] = new_path;
-            kDebug() << "////  SLIDE EDIT, NEW:" << new_path << ", OLD; " << old_props.value("resource");
+            kDebug() << "////  SLIDE EDIT, NEW:" << new_path << ", OLD; " << m_old_props.value("resource");
         }
         int duration;
         if (m_view.slide_duration_format->currentIndex() == 1) {
             // we are in frames mode
             duration = m_view.slide_duration_frames->value();
         } else duration = m_tc.getFrameCount(m_view.slide_duration->text());
-        if (duration != old_props.value("ttl").toInt()) {
+        if (duration != m_old_props.value("ttl").toInt()) {
             m_clipNeedsRefresh = true;
             props["ttl"] = QString::number(duration);
             props["out"] = QString::number(duration * m_count);
         }
-        if (duration * m_count != old_props.value("out").toInt()) {
+
+        if (duration * m_count - 1 != m_old_props.value("out").toInt()) {
             m_clipNeedsRefresh = true;
-            props["out"] = QString::number(duration * m_count);
+            props["out"] = QString::number(duration * m_count - 1);
         }
         if (m_view.slide_fade->isChecked()) {
             int luma_duration;
@@ -444,19 +595,19 @@ QMap <QString, QString> ClipProperties::properties()
                 // we are in frames mode
                 luma_duration = m_view.luma_duration_frames->value();
             } else luma_duration = m_tc.getFrameCount(m_view.luma_duration->text());
-            if (luma_duration != old_props.value("luma_duration").toInt()) {
+            if (luma_duration != m_old_props.value("luma_duration").toInt()) {
                 m_clipNeedsRefresh = true;
                 props["luma_duration"] = QString::number(luma_duration);
             }
             QString lumaFile;
             if (m_view.slide_luma->isChecked())
                 lumaFile = m_view.luma_file->itemData(m_view.luma_file->currentIndex()).toString();
-            if (lumaFile != old_props.value("luma_file")) {
+            if (lumaFile != m_old_props.value("luma_file")) {
                 m_clipNeedsRefresh = true;
                 props["luma_file"] = lumaFile;
             }
         } else {
-            if (!old_props.value("luma_file").isEmpty()) {
+            if (!m_old_props.value("luma_file").isEmpty()) {
                 props["luma_file"].clear();
             }
         }
@@ -480,31 +631,19 @@ void ClipProperties::parseFolder()
 
     QDir dir(m_view.clip_path->text());
     QStringList filters;
-    QString extension;
-    switch (m_view.image_type->currentIndex()) {
-    case TYPE_PNG:
-        filters << "*.png";
-        extension = "/.all.png";
-        break;
-    case TYPE_BMP:
-        filters << "*.bmp";
-        extension = "/.all.bmp";
-        break;
-    case TYPE_GIF:
-        filters << "*.gif";
-        extension = "/.all.gif";
-        break;
-    default:
-        filters << "*.jpg";
-        // TODO: improve jpeg image detection with extension like jpeg, requires change in MLT image producers
-        // << "*.jpeg";
-        extension = "/.all.jpg";
-        break;
-    }
+    filters << "*." + m_view.image_type->itemData(m_view.image_type->currentIndex()).toString();
+    QString extension = "/.all." + m_view.image_type->itemData(m_view.image_type->currentIndex()).toString();
 
     dir.setNameFilters(filters);
     QStringList result = dir.entryList(QDir::Files);
     m_count = result.count();
+    if (m_count == 0) {
+        // no images, do not accept that
+        m_view.slide_info->setText(i18n("No image found"));
+        m_view.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
+        return;
+    }
+    m_view.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
     m_view.slide_info->setText(i18np("1 image found", "%1 images found", m_count));
     QDomElement xml = m_clip->toXML();
     xml.setAttribute("resource", m_view.clip_path->text() + extension);
