@@ -31,12 +31,12 @@
 #include "docclipbase.h"
 #include "guide.h"
 #include "effectslist.h"
+#include "customtrackscene.h"
 
 class ClipItem;
 class AbstractClipItem;
 class AbstractGroupItem;
 class Transition;
-class CustomTrackScene;
 
 class CustomTrackView : public QGraphicsView
 {
@@ -59,7 +59,7 @@ public:
     /** move transition, startPos = (old start, old end), endPos = (new start, new end) */
     void moveTransition(const ItemInfo start, const ItemInfo end, bool m_refresh);
     void resizeClip(const ItemInfo start, const ItemInfo end, bool dontWorry = false);
-    void addClip(QDomElement xml, const QString &clipId, ItemInfo info, EffectsList list = EffectsList(), bool refresh = true);
+    void addClip(QDomElement xml, const QString &clipId, ItemInfo info, EffectsList list = EffectsList(), bool overwrite = false, bool push = false, bool refresh = true);
     void deleteClip(ItemInfo info, bool refresh = true);
     void slotDeleteClipMarker(const QString &comment, const QString &id, const GenTime &position);
     void slotDeleteAllClipMarkers(const QString &id);
@@ -80,11 +80,11 @@ public:
     int duration() const;
     void deleteSelectedClips();
     void cutSelectedClips();
-    void setContextMenu(QMenu *timeline, QMenu *clip, QMenu *transition, QActionGroup *clipTypeGroup);
+    void setContextMenu(QMenu *timeline, QMenu *clip, QMenu *transition, QActionGroup *clipTypeGroup, QMenu *markermenu);
     void checkTrackHeight();
     //QList <TrackInfo> tracksList() const;
     void setTool(PROJECTTOOL tool);
-    void cutClip(ItemInfo info, GenTime cutTime, bool cut);
+    ClipItem *cutClip(ItemInfo info, GenTime cutTime, bool cut, bool execute = true);
     void slotSeekToPreviousSnap();
     void slotSeekToNextSnap();
     double getSnapPointForPos(double pos);
@@ -124,12 +124,19 @@ public:
     void reloadTransitionLumas();
     void updateProjectFps();
     double fps() const;
+    int selectedTrack() const;
+    void selectClip(bool add, bool group = false);
+    void selectTransition(bool add, bool group = false);
+    QStringList extractTransitionsLumas();
+    void setEditMode(EDITMODE mode);
+    void insertClipCut(DocClipBase *clip, int in, int out);
+    void clearSelection();
 
 public slots:
     void setCursorPos(int pos, bool seek = true);
     void moveCursorPos(int delta);
     void updateCursorPos();
-    void slotDeleteEffect(ClipItem *clip, QDomElement effect);
+    void slotDeleteEffect(ClipItem *clip, QDomElement effect, bool affectGroup = true);
     void slotChangeEffectState(ClipItem *clip, int effectPos, bool disable);
     void slotChangeEffectPosition(ClipItem *clip, int currentPos, int newPos);
     void slotUpdateClipEffect(ClipItem *clip, QDomElement oldeffect, QDomElement effect, int ix);
@@ -159,6 +166,10 @@ public slots:
     void slotDeleteTrack(int ix);
     void slotChangeTrack(int ix);
     void clipNameChanged(const QString id, const QString name);
+    void slotTrackUp();
+    void slotTrackDown();
+    void slotSelectTrack(int ix);
+    void insertZoneOverwrite(QStringList data, int in);
 
 protected:
     virtual void drawBackground(QPainter * painter, const QRectF & rect);
@@ -168,6 +179,7 @@ protected:
     virtual void dragLeaveEvent(QDragLeaveEvent * event);
     virtual void dropEvent(QDropEvent * event);
     virtual void wheelEvent(QWheelEvent * e);
+    virtual void keyPressEvent(QKeyEvent * event);
     virtual QStringList mimeTypes() const;
     virtual Qt::DropActions supportedDropActions() const;
 
@@ -210,6 +222,7 @@ private:
     QMenu *m_timelineContextMenu;
     QMenu *m_timelineContextClipMenu;
     QMenu *m_timelineContextTransitionMenu;
+    QMenu *m_markerMenu;
     QAction *m_autoTransition;
     QAction *m_pasteEffectsAction;
     QAction *m_ungroupAction;
@@ -232,6 +245,8 @@ private:
     bool m_blockRefresh;
     AbstractGroupItem *m_selectionGroup;
     QList <ClipItem *> m_waitingThumbs;
+    int m_selectedTrack;
+    int m_spacerOffset;
 
     /** Get the index of the video track that is just below current track */
     int getPreviousVideoTrack(int track);
@@ -253,7 +268,12 @@ private:
     /** Whether an item can be moved to a new position without colliding with similar items */
     bool itemCollision(AbstractClipItem *item, ItemInfo newPos);
     /** Selects all items in the scene rect, and sets ok to false if a group going over several tracks is found in it */
-    QList<QGraphicsItem *> checkForGroups(const QRectF &rect, bool &ok);
+    QList<QGraphicsItem *> checkForGroups(const QRectF &rect, bool *ok);
+    /** Adjust clips under another one when working in overwrite mode */
+    void adjustTimelineClips(EDITMODE mode, ClipItem *item, ItemInfo posinfo, QUndoCommand *command);
+    void adjustTimelineTransitions(EDITMODE mode, Transition *item, QUndoCommand *command);
+    /** Adjust keyframes when pasted to another clip */
+    void adjustKeyfames(GenTime oldstart, GenTime newstart, GenTime duration, QDomElement xml);
 
 private slots:
     void slotRefreshGuides();
@@ -262,6 +282,8 @@ private slots:
     void slotEditTimeLineGuide();
     void slotDeleteTimeLineGuide();
     void slotFetchNextThumbs();
+    void checkTrackSequence(int track);
+    void slotGoToMarker(QAction *action);
 
 signals:
     void cursorMoved(int, int);
@@ -274,9 +296,11 @@ signals:
     void trackHeightChanged();
     void tracksChanged();
     void displayMessage(const QString, MessageType);
-    void showClipFrame(DocClipBase *, const int);
+    void showClipFrame(DocClipBase *, QPoint, const int);
     void doTrackLock(int, bool);
     void updateClipMarkers(DocClipBase *);
+    void updateTrackHeaders();
+    void playMonitor();
 };
 
 #endif
