@@ -47,6 +47,11 @@ namespace Mlt
 class Producer;
 };
 
+struct CutZoneInfo {
+    QPoint zone;
+    QString description;
+};
+
 
 class DocClipBase: public QObject
 {
@@ -173,6 +178,7 @@ Q_OBJECT public:
     void refreshThumbUrl();
     const char *producerProperty(const char *name) const;
     void setProducerProperty(const char *name, const char *data);
+    void resetProducerProperty(const char *name);
     void clearProducers();
     void deleteProducers();
 
@@ -183,8 +189,18 @@ Q_OBJECT public:
 
     /** Returns true is clip is missing but user wants to keep it as placeholder */
     bool isPlaceHolder() const;
+    void setValid();
     static QString getHash(const QString &path);
 
+    void addCutZone(int in, int out, QString desc = QString());
+    bool hasCutZone(QPoint p) const;
+    void removeCutZone(int in, int out);
+    QList <CutZoneInfo> cutZones() const;
+    void updateCutZone(int oldin, int oldout, int in, int out, QString desc = QString());
+
+    bool hasVideoCodec(const QString &codec) const;
+    bool hasAudioCodec(const QString &codec) const;
+
 private:   // Private attributes
 
     /** The number of times this clip is used in the project - the number of references to this clip
@@ -212,6 +228,8 @@ private:   // Private attributes
     /** Wheter the clip is a placeholder (clip missing but user wants to see it) */
     bool m_placeHolder;
 
+    QList <CutZoneInfo> m_cutZones;
+
     void setAudioThumbCreated(bool isDone);
     /** Holds clip infos like fps, size,... */
     QMap <QString, QString> m_properties;
@@ -228,7 +246,6 @@ public slots:
     void updateAudioThumbnail(QMap<int, QMap<int, QByteArray> > data);
     bool slotGetAudioThumbs();
     QList < CommentedTime > commentedSnapMarkers() const;
-    void setSnapMarkers(QList < CommentedTime > markers);
     GenTime findNextSnapMarker(const GenTime & currTime);
     GenTime findPreviousSnapMarker(const GenTime & currTime);
     GenTime hasSnapMarkers(const GenTime & time);
