@@ -115,7 +115,8 @@ DvdWizard::DvdWizard(const QString &url, const QString &profile, QWidget *parent
 
 DvdWizard::~DvdWizard()
 {
-    // m_menuFile.remove();
+    m_authorFile.remove();
+    m_menuFile.remove();
     blockSignals(true);
     delete m_burnMenu;
     if (m_dvdauthor) {
@@ -182,15 +183,18 @@ void DvdWizard::generateDvd()
     //temp6.setAutoRemove(false);
     temp6.open();
 
+    m_menuFile.close();
     m_menuFile.setSuffix(".mpg");
     m_menuFile.setAutoRemove(false);
     m_menuFile.open();
 
+    m_authorFile.close();
     m_authorFile.setSuffix(".xml");
     m_authorFile.setAutoRemove(false);
     m_authorFile.open();
 
     QListWidgetItem *images =  m_status.job_progress->item(0);
+    m_status.job_progress->setCurrentRow(0);
     images->setIcon(KIcon("system-run"));
     qApp->processEvents();
     QMap <QString, QRect> buttons = m_pageMenu->buttonsInfo();
@@ -210,13 +214,14 @@ void DvdWizard::generateDvd()
         if (!m_pageMenu->menuMovie()) {
             // create menu vob file
             QListWidgetItem *vobitem =  m_status.job_progress->item(1);
+            m_status.job_progress->setCurrentRow(1);
             vobitem->setIcon(KIcon("system-run"));
             qApp->processEvents();
 
             QStringList args;
             args.append("-profile");
             if (m_pageMenu->isPalMenu()) args.append("dv_pal");
-            else  args.append("dv_ntsc");
+            else args.append("dv_ntsc");
             args.append(temp4.fileName());
             args.append("in=0");
             args.append("out=100");
@@ -237,6 +242,8 @@ void DvdWizard::generateDvd()
                     vobitem->setIcon(KIcon("dialog-close"));
                     m_status.error_log->append(result);
                     m_status.error_box->setHidden(false);
+                    m_status.button_start->setEnabled(true);
+                    m_status.button_abort->setEnabled(false);
                     return;
                 }
             } else {
@@ -245,6 +252,8 @@ void DvdWizard::generateDvd()
                 m_status.error_log->append("<a name=\"result\" /><br><strong>" + i18n("Rendering job timed out"));
                 m_status.error_log->scrollToAnchor("result");
                 m_status.error_box->setHidden(false);
+                m_status.button_start->setEnabled(true);
+                m_status.button_abort->setEnabled(false);
                 return;
             }
             vobitem->setIcon(KIcon("dialog-ok"));
@@ -253,6 +262,7 @@ void DvdWizard::generateDvd()
 
         // create xml spumux file
         QListWidgetItem *spuitem =  m_status.job_progress->item(2);
+        m_status.job_progress->setCurrentRow(2);
         spuitem->setIcon(KIcon("system-run"));
         qApp->processEvents();
         QDomDocument doc;
@@ -320,6 +330,7 @@ void DvdWizard::generateDvd()
                 spuitem->setIcon(KIcon("dialog-close"));
                 m_status.error_log->append(result);
                 m_status.error_box->setHidden(false);
+                m_status.button_start->setEnabled(true);
                 kDebug() << "/// RENDERING SPUMUX MENU crashed";
                 return;
             }
@@ -329,6 +340,7 @@ void DvdWizard::generateDvd()
             m_status.error_log->append("<a name=\"result\" /><br><strong>" + i18n("Menu job timed out"));
             m_status.error_log->scrollToAnchor("result");
             m_status.error_box->setHidden(false);
+            m_status.button_start->setEnabled(true);
             return;
         }
 
@@ -338,13 +350,14 @@ void DvdWizard::generateDvd()
 
     // create dvdauthor xml
     QListWidgetItem *authitem =  m_status.job_progress->item(3);
+    m_status.job_progress->setCurrentRow(3);
     authitem->setIcon(KIcon("system-run"));
     qApp->processEvents();
-    KIO::NetAccess::mkdir(KUrl(m_status.tmp_folder->url().path() + "/DVD"), this);
+    KIO::NetAccess::mkdir(KUrl(m_status.tmp_folder->url().path(KUrl::AddTrailingSlash) + "DVD"), this);
 
     QDomDocument dvddoc;
     QDomElement auth = dvddoc.createElement("dvdauthor");
-    auth.setAttribute("dest", m_status.tmp_folder->url().path() + "/DVD");
+    auth.setAttribute("dest", m_status.tmp_folder->url().path(KUrl::AddTrailingSlash) + "DVD");
     dvddoc.appendChild(auth);
     QDomElement vmgm = dvddoc.createElement("vmgm");
     auth.appendChild(vmgm);
@@ -388,8 +401,15 @@ void DvdWizard::generateDvd()
         }
         QDomElement menuvob = dvddoc.createElement("vob");
         menuvob.setAttribute("file", m_menuFile.fileName());
-        menuvob.setAttribute("pause", "inf");
         pgc.appendChild(menuvob);
+
+        if (m_pageMenu->loopMovie()) {
+            QDomElement menuloop = dvddoc.createElement("post");
+            nametext = dvddoc.createTextNode("jump titleset 1 menu;");
+            menuloop.appendChild(nametext);
+            pgc.appendChild(menuloop);
+        } else menuvob.setAttribute("pause", "inf");
+
     }
 
     QDomElement titles = dvddoc.createElement("titles");
@@ -511,7 +531,7 @@ void DvdWizard::slotRenderFinished(int exitCode, QProcess::ExitStatus status)
     authitem->setIcon(KIcon("dialog-ok"));
     qApp->processEvents();
     QStringList args;
-    args << "-dvd-video" << "-v" << "-o" << m_status.iso_image->url().path() << m_status.tmp_folder->url().path() + "/DVD";
+    args << "-dvd-video" << "-v" << "-o" << m_status.iso_image->url().path() << m_status.tmp_folder->url().path(KUrl::AddTrailingSlash) + "DVD";
 
     if (m_mkiso) {
         m_mkiso->blockSignals(true);
@@ -524,6 +544,7 @@ void DvdWizard::slotRenderFinished(int exitCode, QProcess::ExitStatus status)
     connect(m_mkiso, SIGNAL(readyReadStandardOutput()), this, SLOT(slotShowIsoInfo()));
     m_mkiso->setProcessChannelMode(QProcess::MergedChannels);
     QListWidgetItem *isoitem =  m_status.job_progress->item(4);
+    m_status.job_progress->setCurrentRow(4);
     isoitem->setIcon(KIcon("system-run"));
     if (!KStandardDirs::findExe("genisoimage").isEmpty()) m_mkiso->start("genisoimage", args);
     else m_mkiso->start("mkisofs", args);
@@ -596,9 +617,7 @@ void DvdWizard::slotIsoFinished(int exitCode, QProcess::ExitStatus status)
 
 void DvdWizard::cleanup()
 {
-    m_authorFile.remove();
-    m_menuFile.remove();
-    KIO::NetAccess::del(KUrl(m_status.tmp_folder->url().path() + "/DVD"), this);
+    KIO::NetAccess::del(KUrl(m_status.tmp_folder->url().path(KUrl::AddTrailingSlash) + "DVD"), this);
 }
 
 
@@ -628,13 +647,13 @@ void DvdWizard::slotGenerate()
     for (int i = 0; i < m_status.job_progress->count(); i++)
         m_status.job_progress->item(i)->setIcon(KIcon());
     QString warnMessage;
-    if (KIO::NetAccess::exists(KUrl(m_status.tmp_folder->url().path() + "/DVD"), KIO::NetAccess::SourceSide, this))
-        warnMessage.append(i18n("Folder %1 already exists. Overwrite?" + '\n', m_status.tmp_folder->url().path() + "/DVD"));
+    if (KIO::NetAccess::exists(KUrl(m_status.tmp_folder->url().path(KUrl::AddTrailingSlash) + "DVD"), KIO::NetAccess::SourceSide, this))
+        warnMessage.append(i18n("Folder %1 already exists. Overwrite?" + '\n', m_status.tmp_folder->url().path(KUrl::AddTrailingSlash) + "DVD"));
     if (KIO::NetAccess::exists(KUrl(m_status.iso_image->url().path()), KIO::NetAccess::SourceSide, this))
         warnMessage.append(i18n("Image file %1 already exists. Overwrite?", m_status.iso_image->url().path()));
 
     if (warnMessage.isEmpty() || KMessageBox::questionYesNo(this, warnMessage) == KMessageBox::Yes) {
-        KIO::NetAccess::del(KUrl(m_status.tmp_folder->url().path() + "/DVD"), this);
+        KIO::NetAccess::del(KUrl(m_status.tmp_folder->url().path(KUrl::AddTrailingSlash) + "DVD"), this);
         QTimer::singleShot(300, this, SLOT(generateDvd()));
         m_status.button_preview->setEnabled(false);
         m_status.button_burn->setEnabled(false);
