@@ -33,58 +33,68 @@
 EffectsListView::EffectsListView(QWidget *parent) :
         QWidget(parent)
 {
-    m_ui.setupUi(this);
+    setupUi(this);
 
     QMenu *menu = new QMenu(this);
     m_effectsList = new EffectsListWidget(menu);
-    QVBoxLayout *lyr = new QVBoxLayout(m_ui.effectlistframe);
+    QVBoxLayout *lyr = new QVBoxLayout(effectlistframe);
     lyr->addWidget(m_effectsList);
     lyr->setContentsMargins(0, 0, 0, 0);
-    m_ui.search_effect->setListWidget(m_effectsList);
-    m_ui.buttonInfo->setIcon(KIcon("help-about"));
+    search_effect->setTreeWidget(m_effectsList);
+    buttonInfo->setIcon(KIcon("help-about"));
+    setFocusPolicy(Qt::StrongFocus);
 
     if (KdenliveSettings::showeffectinfo()) {
-        m_ui.buttonInfo->setDown(true);
-    } else m_ui.infopanel->hide();
+        buttonInfo->setDown(true);
+    } else infopanel->hide();
     menu->addAction(KIcon("edit-delete"), i18n("Delete effect"), this, SLOT(slotRemoveEffect()));
 
-    connect(m_ui.type_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(filterList(int)));
-    connect(m_ui.buttonInfo, SIGNAL(clicked()), this, SLOT(showInfoPanel()));
+    connect(type_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(filterList(int)));
+    connect(buttonInfo, SIGNAL(clicked()), this, SLOT(showInfoPanel()));
     connect(m_effectsList, SIGNAL(itemSelectionChanged()), this, SLOT(slotUpdateInfo()));
-    connect(m_effectsList, SIGNAL(doubleClicked(QListWidgetItem *, const QPoint &)), this, SLOT(slotEffectSelected()));
+    connect(m_effectsList, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotEffectSelected()));
 
-    m_effectsList->setCurrentRow(0);
+    //m_effectsList->setCurrentRow(0);
 }
 
 
+void EffectsListView::focusInEvent(QFocusEvent * /*event*/)
+{
+    search_effect->setFocus();
+}
+
 void EffectsListView::filterList(int pos)
 {
-    QListWidgetItem *item;
-    for (int i = 0; i < m_effectsList->count(); i++) {
-        item = m_effectsList->item(i);
-        if (pos == 0) item->setHidden(false);
-        else if (item->data(Qt::UserRole).toInt() == pos) item->setHidden(false);
-        else item->setHidden(true);
+    QTreeWidgetItem *item;
+    QTreeWidgetItem *folder;
+    for (int i = 0; i < m_effectsList->topLevelItemCount(); i++) {
+        folder = m_effectsList->topLevelItem(i);
+        for (int j = 0; j < folder->childCount(); j++) {
+            item = folder->child(j);
+            if (pos == 0) item->setHidden(false);
+            else if (item->data(0, Qt::UserRole).toInt() == pos) item->setHidden(false);
+            else item->setHidden(true);
+        }
     }
     item = m_effectsList->currentItem();
-    if (item) {
+    /*if (item) {
         if (item->isHidden()) {
             int i;
-            for (i = 0; i < m_effectsList->count() && m_effectsList->item(i)->isHidden(); i++) /*do nothing*/;
+            for (i = 0; i < m_effectsList->count() && m_effectsList->item(i)->isHidden(); i++); //do nothing
             m_effectsList->setCurrentRow(i);
         } else m_effectsList->scrollToItem(item);
-    }
+    }*/
 }
 
 void EffectsListView::showInfoPanel()
 {
-    if (m_ui.infopanel->isVisible()) {
-        m_ui.infopanel->setVisible(false);
-        m_ui.buttonInfo->setDown(false);
+    if (infopanel->isVisible()) {
+        infopanel->setVisible(false);
+        buttonInfo->setDown(false);
         KdenliveSettings::setShoweffectinfo(false);
     } else {
-        m_ui.infopanel->setVisible(true);
-        m_ui.buttonInfo->setDown(true);
+        infopanel->setVisible(true);
+        buttonInfo->setDown(true);
         KdenliveSettings::setShoweffectinfo(true);
     }
 }
@@ -97,12 +107,7 @@ void EffectsListView::slotEffectSelected()
 
 void EffectsListView::slotUpdateInfo()
 {
-    m_ui.infopanel->setText(m_effectsList->currentInfo());
-}
-
-KListWidget *EffectsListView::listView()
-{
-    return m_effectsList;
+    infopanel->setText(m_effectsList->currentInfo());
 }
 
 void EffectsListView::reloadEffectList()
@@ -112,8 +117,8 @@ void EffectsListView::reloadEffectList()
 
 void EffectsListView::slotRemoveEffect()
 {
-    QListWidgetItem *item = m_effectsList->currentItem();
-    QString effectId = item->text();
+    QTreeWidgetItem *item = m_effectsList->currentItem();
+    QString effectId = item->text(0);
     QString path = KStandardDirs::locateLocal("appdata", "effects/", true);
 
     QDir directory = QDir(path);
