@@ -25,24 +25,27 @@
 
 #include "ui_effectlist_ui.h"
 #include "gentime.h"
+
 #include <QDomElement>
+#include <QFocusEvent>
 
 class EffectsList;
 class EffectsListWidget;
-class KListWidget;
+class QTreeWidget;
 
-class EffectsListView : public QWidget
+class EffectsListView : public QWidget, public Ui::EffectList_UI
 {
     Q_OBJECT
 
 public:
     EffectsListView(QWidget *parent = 0);
-    KListWidget *listView();
     void reloadEffectList();
     //void slotAddEffect(GenTime pos, int track, QString name);
 
+protected:
+    virtual void focusInEvent(QFocusEvent * event);
+
 private:
-    Ui::EffectList_UI m_ui;
     EffectsListWidget *m_effectsList;
 
 private slots:
