@@ -21,10 +21,8 @@
 #include "ui_boolval_ui.h"
 #include "ui_colorval_ui.h"
 #include "ui_wipeval_ui.h"
-#include "ui_keyframeeditor_ui.h"
 #include "complexparameter.h"
 #include "geometryval.h"
-#include "keyframeedit.h"
 #include "positionedit.h"
 #include "effectslist.h"
 #include "kdenlivesettings.h"
@@ -68,7 +66,8 @@ EffectStackEdit::EffectStackEdit(QWidget *parent) :
         QScrollArea(parent),
         m_in(0),
         m_out(0),
-        m_frameSize(QPoint())
+        m_frameSize(QPoint()),
+        m_keyframeEditor(NULL)
 {
     m_baseWidget = new QWidget(this);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -87,6 +86,7 @@ EffectStackEdit::EffectStackEdit(QWidget *parent) :
 EffectStackEdit::~EffectStackEdit()
 {
     iconCache.clear();
+    delete m_baseWidget;
 }
 
 void EffectStackEdit::setFrameSize(QPoint p)
@@ -122,6 +122,8 @@ void EffectStackEdit::updateParameter(const QString &name, const QString &value)
 void EffectStackEdit::transferParamDesc(const QDomElement d, int in, int out)
 {
     clearAllItems();
+    if (m_keyframeEditor) delete m_keyframeEditor;
+    m_keyframeEditor = NULL;
     m_params = d;
     m_in = in;
     m_out = out;
@@ -149,18 +151,18 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int in, int out)
         QString value = pa.attribute("value").isNull() ?
                         pa.attribute("default") : pa.attribute("value");
 
-        if (type == "geometry") {
-            /*pa.setAttribute("namedesc", "X;Y;Width;Height;Transparency");
-            pa.setAttribute("format", "%d%,%d%:%d%x%d%:%d");
-            pa.setAttribute("min", "-500;-500;0;0;0");
-            pa.setAttribute("max", "500;500;200;200;100");*/
-        } else if (type == "complex") {
-            //pa.setAttribute("namedesc",pa.attribute("name"));
+        /** Currently supported parameter types are:
+            * constant (=double): a slider with an integer value (use the "factor" attribute to divide the value so that you can get a double
+            * list: a combobox containing a list of values to choose
+            * bool: a checkbox
+            * complex: designed for keyframe parameters, but old and not finished, do not use
+            * geometry: a rectangle that can be moved & resized, with possible keyframes, used in composite transition
+            * keyframe: a list widget with a list of entries (position and value)
+            * color: a color chooser button
+            * position: a slider representing the position of a frame in the current clip
+            * wipe: a widget designed for the wipe transition, allowing to choose a position (left, right, top,...)
+        */
 
-        }
-
-
-        //TODO constant, list, bool, complex , color, geometry, position
         if (type == "double" || type == "constant") {
             int min;
             int max;
@@ -225,22 +227,26 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int in, int out)
             m_valueItems[paramName+"complex"] = pl;
             connect(pl, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
         } else if (type == "geometry") {
-            Geometryval *geo = new Geometryval(m_profile, m_frameSize);
+            Geometryval *geo = new Geometryval(m_profile, m_frameSize, m_in);
             geo->setupParam(pa, minFrame, maxFrame);
             m_vbox->addWidget(geo);
             m_valueItems[paramName+"geometry"] = geo;
             connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
             connect(geo, SIGNAL(seekToPos(int)), this, SLOT(slotSeekToPos(int)));
-        } else if (type == "keyframe") {
+        } else if (type == "keyframe" || type == "simplekeyframe") {
             // keyframe editor widget
             kDebug() << "min: " << m_in << ", MAX: " << m_out;
-            KeyframeEdit *geo = new KeyframeEdit(pa, m_out - m_in - 1, pa.attribute("min").toInt(), pa.attribute("max").toInt(), m_timecode);
-            //geo->setupParam(100, pa.attribute("min").toInt(), pa.attribute("max").toInt(), pa.attribute("keyframes"));
-            //connect(geo, SIGNAL(seekToPos(int)), this, SLOT(slotSeekToPos(int)));
-            //geo->setupParam(pa, minFrame, maxFrame);
-            m_vbox->addWidget(geo);
-            m_valueItems[paramName+"keyframe"] = geo;
-            connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
+            if (m_keyframeEditor == NULL) {
+                KeyframeEdit *geo = new KeyframeEdit(pa, m_in, m_in + m_out, pa.attribute("min").toInt(), pa.attribute("max").toInt(), m_timecode, e.attribute("active_keyframe", "-1").toInt());
+                m_vbox->addWidget(geo);
+                m_valueItems[paramName+"keyframe"] = geo;
+                m_keyframeEditor = geo;
+                connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
+                connect(geo, SIGNAL(seekToPos(int)), this, SLOT(slotSeekToPos(int)));
+            } else {
+                // we already have a keyframe editor, so just add another column for the new param
+                m_keyframeEditor->addParameter(pa);
+            }
         } else if (type == "color") {
             Colorval *cval = new Colorval;
             cval->setupUi(toFillin);
@@ -333,7 +339,7 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int in, int out)
 
 void EffectStackEdit::slotSeekToPos(int pos)
 {
-    emit seekTimeline(m_in + pos);
+    emit seekTimeline(pos);
 }
 
 wipeInfo EffectStackEdit::getWipeInfo(QString value)
@@ -420,8 +426,8 @@ void EffectStackEdit::collectAllParameters()
         else if (type == "position") paramName.append("position");
         else if (type == "geometry") paramName.append("geometry");
         else if (type == "keyframe") paramName.append("keyframe");
-        if (!m_valueItems.contains(paramName)) {
-            // kDebug() << "// Param: " << paramName << " NOT FOUND";
+        if (type != "simplekeyframe" && !m_valueItems.contains(paramName)) {
+            kDebug() << "// Param: " << paramName << " NOT FOUND";
             continue;
         }
 
@@ -485,8 +491,12 @@ void EffectStackEdit::collectAllParameters()
             else info.end = RIGHT;
             info.endTransparency = wp->end_transp->value();
             setValue = getWipeString(info);
+        } else if ((type == "simplekeyframe" || type == "keyframe") && m_keyframeEditor) {
+            QString realName = i18n(na.toElement().text().toUtf8().data());
+            QString val = m_keyframeEditor->getValue(realName);
+            kDebug() << "SET VALUE: " << val;
+            namenode.item(i).toElement().setAttribute("keyframes", val);
         }
-
         if (!setValue.isNull()) {
             pa.attributes().namedItem("value").setNodeValue(setValue);
         }
@@ -535,5 +545,6 @@ void EffectStackEdit::clearAllItems()
         delete child;
         if (wid) delete wid;
     }
+    m_keyframeEditor = NULL;
     blockSignals(false);
 }
