@@ -24,7 +24,7 @@
 #include <QGraphicsScene>
 
 enum resizeModes {NoResize, TopLeft, BottomLeft, TopRight, BottomRight, Left, Right, Up, Down};
-enum TITLETOOL { TITLE_NONE = -1, TITLE_SELECT = 0, TITLE_RECTANGLE = 1, TITLE_TEXT = 2, TITLE_IMAGE = 3 };
+enum TITLETOOL { TITLE_SELECT = 0, TITLE_RECTANGLE = 1, TITLE_TEXT = 2, TITLE_IMAGE = 3 };
 
 class GraphicsSceneRectMove: public QGraphicsScene
 {
@@ -39,6 +39,9 @@ public:
     TITLETOOL tool();
     void clearTextSelection();
 
+public slots:
+    void slotUpdateFontSize(int s);
+
 protected:
     virtual void keyPressEvent(QKeyEvent * keyEvent);
     virtual void mousePressEvent(QGraphicsSceneMouseEvent*);
@@ -56,6 +59,7 @@ private:
     QPointF m_sceneClickPoint;
     TITLETOOL m_tool;
     QPoint m_clickPoint;
+    int m_fontSize;
 
 signals:
     void itemMoved();
