@@ -35,6 +35,10 @@ public:
     //virtual ~HeaderTrack();
     void setLock(bool lock);
     void adjustSize(int height);
+    void setSelectedIndex(int ix);
+
+protected:
+    virtual void mousePressEvent(QMouseEvent * event);
 
 private:
     int m_index;
@@ -58,6 +62,7 @@ signals:
     void deleteTrack(int);
     void changeTrack(int);
     void renameTrack(int);
+    void selectTrack(int);
 };
 
 #endif
