@@ -75,18 +75,24 @@ class KeyframeEdit : public QWidget, public Ui::KeyframeEditor_UI
 {
     Q_OBJECT
 public:
-    explicit KeyframeEdit(QDomElement e, int maxFrame, int minVal, int maxVal, Timecode tc, QWidget* parent = 0);
+    explicit KeyframeEdit(QDomElement e, int minFrame, int maxFrame, int minVal, int maxVal, Timecode tc, int active_keyframe, QWidget* parent = 0);
     virtual ~KeyframeEdit();
-    void setupParam(QDomElement e = QDomElement());
+    void setupParam();
+    void addParameter(QDomElement e);
+    const QString getValue(const QString &name);
 
 private:
-    QDomElement m_param;
+    QList <QDomElement> m_params;
+    int m_min;
     int m_max;
     int m_minVal;
     int m_maxVal;
     Timecode m_timecode;
     int m_previousPos;
-    KeyItemDelegate *m_delegate;
+    //KeyItemDelegate *m_delegate;
+    void generateAllParams();
+    QGridLayout *m_slidersLayout;
+    int m_active_keyframe;
 
 public slots:
 
@@ -94,10 +100,12 @@ public slots:
 private slots:
     void slotDeleteKeyframe();
     void slotAddKeyframe();
-    void slotGenerateParams(QTreeWidgetItem *item = NULL, int column = -1);
-    void slotAdjustKeyframeInfo();
+    void slotGenerateParams(int row, int column);
+    void slotAdjustKeyframeInfo(bool seek = true);
+    void slotAdjustKeyframePos(int value);
     void slotAdjustKeyframeValue(int value);
-    void slotSaveCurrentParam(QTreeWidgetItem *item, int column);
+    void slotSetSeeking(int state);
+    //void slotSaveCurrentParam(QTreeWidgetItem *item, int column);
 
 signals:
     void parameterChanged();
