@@ -166,11 +166,13 @@ private:
     KAction *m_buttonVideoThumbs;
     KAction *m_buttonShowMarkers;
     KAction *m_buttonFitZoom;
+    KAction *m_normalEditTool;
+    KAction *m_overwriteEditTool;
+    KAction *m_insertEditTool;
     KAction *m_buttonSelectTool;
     KAction *m_buttonRazorTool;
     KAction *m_buttonSpacerTool;
     KAction *m_buttonSnap;
-    QActionGroup *m_toolGroup;
     KAction *m_saveAction;
     KAction *m_closeAction;
     QSlider *m_zoomSlider;
@@ -199,10 +201,11 @@ private:
                    QMenu *menu, const char *member,
                    QActionGroup *actionGroup);
     void aboutPlugins();
+    int getNewStuff(const QString &configFile = QString());
     QStringList m_pluginFileNames;
     QByteArray m_timelineState;
     void loadTranscoders();
-
+    QPixmap createSchemePreviewIcon(const KSharedConfigPtr &config);
 
 public slots:
     void openFile(const KUrl &url);
@@ -211,7 +214,7 @@ public slots:
     Q_SCRIPTABLE void setRenderingFinished(const QString &url, int status, const QString &error);
 
 private slots:
-    void newFile(bool showProjectSettings = true);
+    void newFile(bool showProjectSettings = true, bool force = false);
     void queryQuit();
     void activateDocument();
     void connectDocument(TrackView*, KdenliveDoc*);
@@ -248,6 +251,13 @@ private slots:
     void slotDeleteAllClipMarkers();
     void slotEditClipMarker();
     void slotCutTimelineClip();
+    void slotInsertClipOverwrite();
+    void slotSelectTimelineClip();
+    void slotSelectTimelineTransition();
+    void slotDeselectTimelineClip();
+    void slotDeselectTimelineTransition();
+    void slotSelectAddTimelineClip();
+    void slotSelectAddTimelineTransition();
     void slotAddVideoEffect(QAction *result);
     void slotAddAudioEffect(QAction *result);
     void slotAddCustomEffect(QAction *result);
@@ -257,14 +267,18 @@ private slots:
     void slotShuttleButton(int code);
 #endif /* NO_JOGSHUTTLE */
     void slotShowClipProperties(DocClipBase *clip);
+    void slotShowClipProperties(QList <DocClipBase *>cliplist, QMap<QString, QString> commonproperties);
     void slotActivateEffectStackView();
     void slotActivateTransitionView(Transition *);
     void slotChangeTool(QAction * action);
+    void slotChangeEdit(QAction * action);
     void slotSetTool(PROJECTTOOL tool);
     void slotSnapForward();
     void slotSnapRewind();
     void slotClipStart();
     void slotClipEnd();
+    void slotZoneStart();
+    void slotZoneEnd();
     void slotFind();
     void findTimeout();
     void slotFindNext();
@@ -288,6 +302,8 @@ private slots:
 
     void slotSetInPoint();
     void slotSetOutPoint();
+    void slotResizeItemStart();
+    void slotResizeItemEnd();
     void configureNotifications();
     void slotInsertTrack(int ix = 0);
     void slotDeleteTrack(int ix = 0);
@@ -309,7 +325,7 @@ private slots:
     void slotMaximizeCurrent(bool show);
     void slotTranscode(KUrl::List urls = KUrl::List());
     void slotTranscodeClip();
-    void slotSetDocumentRenderProfile(const QString &dest, const QString &name, const QString &file);
+    void slotSetDocumentRenderProfile(const QString &dest, const QString &group, const QString &name, const QString &file);
     void slotPrepareRendering(bool scriptExport, bool zoneOnly, const QString &chapterFile);
     void slotUpdateTimecodeFormat(int ix);
     /** Removes the focus of anything */
@@ -320,6 +336,12 @@ private slots:
     void slotRevert();
     void slotShutdown();
     void slotUpdateTrackInfo();
+    /** \brief Change color scheme */
+    void slotChangePalette(QAction *action, const QString &themename = QString());
+    void slotSwitchMonitors();
+    void slotInsertZoneToTree();
+    void slotInsertZoneToTimeline();
+    void slotDeleteProjectClips(QStringList ids, QMap<QString, QString> folderids);
 
 signals:
     Q_SCRIPTABLE void abortRenderJob(const QString &url);
