@@ -47,7 +47,7 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
         m_name(name),
         m_monitorManager(manager),
         m_currentClip(NULL),
-        m_ruler(new SmallRuler()),
+        m_ruler(new SmallRuler(m_monitorManager)),
         m_overlay(NULL),
         m_isActive(false),
         m_scale(1),
@@ -152,9 +152,7 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
 
     connect(m_ruler, SIGNAL(seekRenderer(int)), this, SLOT(slotSeek(int)));
     connect(render, SIGNAL(durationChanged(int)), this, SLOT(adjustRulerSize(int)));
-    connect(render, SIGNAL(rendererPosition(int)), this, SLOT(seekCursor(int)));
     connect(render, SIGNAL(rendererStopped(int)), this, SLOT(rendererStopped(int)));
-    connect(render, SIGNAL(blockMonitors()), this, SIGNAL(blockMonitors()));
 
     //render->createVideoXWindow(m_ui.video_frame->winId(), -1);
 
@@ -420,7 +418,6 @@ void Monitor::mouseMoveEvent(QMouseEvent *event)
         mimeData->setData("kdenlive/clip", data);
         drag->setMimeData(mimeData);
         QPixmap pix = m_currentClip->thumbnail();
-        kDebug() << "/ / / /CLIP DRAGGED PIXMAP: " << pix.width() << "x" << pix.height();
         drag->setPixmap(pix);
         drag->setHotSpot(QPoint(0, 50));
         drag->start(Qt::MoveAction);
@@ -511,7 +508,9 @@ bool Monitor::isActive() const
 
 void Monitor::activateMonitor()
 {
-    if (!m_isActive) m_monitorManager->switchMonitors(); //m_monitorManager->activateMonitor(m_name);
+    if (!m_isActive) {
+        m_monitorManager->slotSwitchMonitors(m_name == "clip");
+    }
 }
 
 void Monitor::setTimePos(const QString &pos)
@@ -561,7 +560,7 @@ void Monitor::slotStart()
     activateMonitor();
     render->play(0);
     render->seekToFrame(0);
-    emit renderPosition(0);
+    //emit renderPosition(0);
 }
 
 void Monitor::slotEnd()
@@ -569,7 +568,7 @@ void Monitor::slotEnd()
     activateMonitor();
     render->play(0);
     render->seekToFrame(render->getLength());
-    emit renderPosition(render->seekFramePosition());
+    //emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotZoneStart()
@@ -631,26 +630,23 @@ void Monitor::slotForwardOneFrame(int diff)
 void Monitor::seekCursor(int pos)
 {
     activateMonitor();
-    checkOverlay();
-    if (m_frametimecode) m_timePos->setText(QString::number(pos));
-    else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
-    m_ruler->slotNewValue(pos);
+    if (m_ruler->slotNewValue(pos)) {
+        checkOverlay();
+        if (m_frametimecode) m_timePos->setText(QString::number(pos));
+        else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
+    }
 }
 
 void Monitor::rendererStopped(int pos)
 {
-    if (m_currentClip != NULL && m_playAction->isChecked()) {
-        // Clip monitor
-        if (pos >= m_length - 1) {
-            slotStart();
-            return;
-        }
+    if (m_ruler->slotNewValue(pos)) {
+        checkOverlay();
+        if (m_frametimecode) m_timePos->setText(QString::number(pos));
+        else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
     }
-    m_ruler->slotNewValue(pos);
-    checkOverlay();
-    if (m_frametimecode) m_timePos->setText(QString::number(pos));
-    else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
+    disconnect(m_playAction, SIGNAL(triggered()), this, SLOT(slotPlay()));
     m_playAction->setChecked(false);
+    connect(m_playAction, SIGNAL(triggered()), this, SLOT(slotPlay()));
     m_playAction->setIcon(m_playIcon);
 }
 
@@ -680,20 +676,20 @@ void Monitor::adjustRulerSize(int length)
 void Monitor::stop()
 {
     m_isActive = false;
+    disconnect(render, SIGNAL(rendererPosition(int)), this, SLOT(seekCursor(int)));
     if (render) render->stop();
-    //kDebug()<<"/// MONITOR RENDER STOP";
 }
 
 void Monitor::start()
 {
     m_isActive = true;
     if (render) render->start();
-    //kDebug()<<"/// MONITOR RENDER START";
+    connect(render, SIGNAL(rendererPosition(int)), this, SLOT(seekCursor(int)));
 }
 
 void Monitor::refreshMonitor(bool visible)
 {
-    if (visible && render) {
+    if (visible && render && !m_isActive) {
         activateMonitor();
         render->doRefresh(); //askForRefresh();
     }
@@ -742,23 +738,28 @@ void Monitor::slotLoopZone()
     m_playAction->setIcon(m_pauseIcon);
 }
 
-void Monitor::slotSetXml(DocClipBase *clip, const int position)
+void Monitor::slotSetXml(DocClipBase *clip, QPoint zone, const int position)
 {
     if (render == NULL) return;
-    activateMonitor();
-    if (!clip && m_currentClip != NULL) {
+    if (clip == NULL && m_currentClip != NULL) {
         m_currentClip = NULL;
+        m_length = -1;
         render->setProducer(NULL, -1);
         return;
     }
+    if (m_currentClip != NULL) activateMonitor();
     if (clip != m_currentClip) {
         m_currentClip = clip;
         updateMarkers(clip);
         if (render->setProducer(clip->producer(), position) == -1) {
             // MLT CONSUMER is broken
-            emit blockMonitors();
+            kDebug(QtWarningMsg) << "ERROR, Cannot start monitor";
         }
     } else if (position != -1) render->seek(GenTime(position, m_monitorManager->timecode().fps()));
+    if (!zone.isNull()) {
+        m_ruler->setZone(zone.x(), zone.y());
+        render->seek(GenTime(zone.x(), m_monitorManager->timecode().fps()));
+    }
 }
 
 void Monitor::slotOpenFile(const QString &file)
@@ -848,6 +849,16 @@ void Monitor::updateTimecodeFormat()
     }
 }
 
+QStringList Monitor::getZoneInfo() const
+{
+    QStringList result;
+    if (m_currentClip == NULL) return result;
+    result << m_currentClip->getId();
+    QPoint zone = m_ruler->zone();
+    result << QString::number(zone.x()) << QString::number(zone.y());
+    return result;
+}
+
 
 MonitorRefresh::MonitorRefresh(QWidget* parent) : \
         QWidget(parent),
