@@ -139,7 +139,7 @@ private slots:
 
 public slots:
     void slotOpenFile(const QString &);
-    void slotSetXml(DocClipBase *clip, const int position = -1);
+    void slotSetXml(DocClipBase *clip, QPoint zone = QPoint(), const int position = -1);
     void initMonitor();
     void refreshMonitor(bool visible = true);
     void slotSeek(int pos);
@@ -165,6 +165,7 @@ public slots:
     void slotSeekToPreviousSnap();
     void adjustRulerSize(int length);
     void setTimePos(const QString &pos);
+    QStringList getZoneInfo() const;
 
 signals:
     void renderPosition(int);
@@ -173,7 +174,6 @@ signals:
     void adjustMonitorSize();
     void zoneUpdated(QPoint);
     void saveZone(Render *, QPoint);
-    void blockMonitors();
 };
 
 #endif
