@@ -44,8 +44,6 @@ void MonitorManager::initMonitors(Monitor *clipMonitor, Monitor *projectMonitor)
 {
     m_clipMonitor = clipMonitor;
     m_projectMonitor = projectMonitor;
-    connect(m_clipMonitor, SIGNAL(blockMonitors()), this, SLOT(slotBlockMonitors()));
-    connect(m_projectMonitor, SIGNAL(blockMonitors()), this, SLOT(slotBlockMonitors()));
 }
 
 void MonitorManager::activateMonitor(QString name)
@@ -59,22 +57,20 @@ void MonitorManager::activateMonitor(QString name)
     } else {
         m_clipMonitor->stop();
         m_projectMonitor->start();
-        m_projectMonitor->raise();
         emit raiseClipMonitor(false);
     }
     m_activeMonitor = name;
 }
 
-void MonitorManager::switchMonitors()
+void MonitorManager::slotSwitchMonitors(bool activateClip)
 {
     if (m_blocked || m_clipMonitor == NULL) return;
-    if (m_clipMonitor->isActive()) {
+    if (!activateClip && m_clipMonitor->isActive()) {
         m_clipMonitor->stop();
         m_projectMonitor->start();
-        m_projectMonitor->raise();
         m_activeMonitor = m_projectMonitor->name();
         emit raiseClipMonitor(false);
-    } else {
+    } else if (activateClip && m_projectMonitor->isActive()) {
         m_projectMonitor->stop();
         m_clipMonitor->start();
         m_activeMonitor = m_clipMonitor->name();
@@ -174,17 +170,5 @@ void MonitorManager::slotResetProfiles()
     //m_projectMonitor->refreshMonitor(true);
 }
 
-void MonitorManager::slotBlockMonitors()
-{
-    m_blocked = true;
-    if (m_clipMonitor) {
-        m_clipMonitor->blockSignals(true);
-        m_clipMonitor->setEnabled(false);
-    }
-    if (m_projectMonitor) {
-        m_projectMonitor->blockSignals(true);
-        m_projectMonitor->setEnabled(false);
-    }
-}
 
 #include "monitormanager.moc"
