@@ -28,57 +28,43 @@
 #include <KIcon>
 
 const int DurationRole = Qt::UserRole + 1;
-
-// folder
-ProjectItem::ProjectItem(QTreeWidget * parent, const QStringList & strings, const QString &clipId) :
-        QTreeWidgetItem(parent, strings),
-        m_groupname(strings.at(1)),
-        m_clipType(FOLDER),
-        m_clipId(clipId),
-        m_clip(NULL)
-{
-    setSizeHint(0, QSize(65, 45));
-    setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
-    setIcon(0, KIcon("folder"));
-    setToolTip(1, "<b>" + i18n("Folder"));
-    //kDebug() << "Constructed as folder, with clipId: " << m_clipId << ", and groupname: " << m_groupname;
-}
+const int itemHeight = 38;
 
 ProjectItem::ProjectItem(QTreeWidget * parent, DocClipBase *clip) :
-        QTreeWidgetItem(parent)
+        QTreeWidgetItem(parent, PROJECTCLIPTYPE)
 {
-    setSizeHint(0, QSize(65, 45));
-    setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
+    setSizeHint(0, QSize(itemHeight * 3, itemHeight));
+    if (clip->isPlaceHolder()) setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+    else setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
     m_clip = clip;
     m_clipId = clip->getId();
     QString name = m_clip->getProperty("name");
     if (name.isEmpty()) name = KUrl(m_clip->getProperty("resource")).fileName();
     m_clipType = (CLIPTYPE) m_clip->getProperty("type").toInt();
     if (m_clipType != UNKNOWN) slotSetToolTip();
-    setText(1, name);
-    setText(2, m_clip->description());
-    if ((m_clip->clipType() == AV || m_clip->clipType() == AUDIO) && KdenliveSettings::audiothumbnails()) m_clip->askForAudioThumbs();
+    setText(0, name);
+    setText(1, m_clip->description());
     GenTime duration = m_clip->duration();
-    if (duration != GenTime()) setData(1, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
+    if (duration != GenTime()) setData(0, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
     //setFlags(Qt::NoItemFlags);
     //kDebug() << "Constructed with clipId: " << m_clipId;
 }
 
 ProjectItem::ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip) :
-        QTreeWidgetItem(parent)
+        QTreeWidgetItem(parent, PROJECTCLIPTYPE)
 {
-    setSizeHint(0, QSize(65, 45));
-    setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
+    setSizeHint(0, QSize(itemHeight * 3, itemHeight));
+    if (clip->isPlaceHolder()) setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+    else setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
     m_clip = clip;
     m_clipId = clip->getId();
     QString name = m_clip->getProperty("name");
     if (name.isEmpty()) name = KUrl(m_clip->getProperty("resource")).fileName();
     m_clipType = (CLIPTYPE) m_clip->getProperty("type").toInt();
-    setText(1, name);
-    setText(2, m_clip->description());
-    if ((m_clip->clipType() == AV || m_clip->clipType() == AUDIO) && KdenliveSettings::audiothumbnails()) m_clip->askForAudioThumbs();
+    setText(0, name);
+    setText(1, m_clip->description());
     GenTime duration = m_clip->duration();
-    if (duration != GenTime()) setData(1, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
+    if (duration != GenTime()) setData(0, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
     //setFlags(Qt::NoItemFlags);
     //kDebug() << "Constructed with clipId: " << m_clipId;
 }
@@ -88,6 +74,12 @@ ProjectItem::~ProjectItem()
 {
 }
 
+//static
+int ProjectItem::itemDefaultHeight()
+{
+    return itemHeight;
+}
+
 int ProjectItem::numReferences() const
 {
     if (!m_clip) return 0;
@@ -109,11 +101,6 @@ int ProjectItem::clipMaxDuration() const
     return m_clip->getProperty("duration").toInt();
 }
 
-bool ProjectItem::isGroup() const
-{
-    return m_clipType == FOLDER;
-}
-
 QStringList ProjectItem::names() const
 {
     QStringList result;
@@ -130,14 +117,14 @@ QDomElement ProjectItem::toXml() const
 
 const KUrl ProjectItem::clipUrl() const
 {
-    if (m_clipType != COLOR && m_clipType != VIRTUAL && m_clipType != UNKNOWN && m_clipType != FOLDER)
+    if (m_clipType != COLOR && m_clipType != VIRTUAL && m_clipType != UNKNOWN)
         return KUrl(m_clip->getProperty("resource"));
     else return KUrl();
 }
 
 void ProjectItem::changeDuration(int frames)
 {
-    setData(1, DurationRole, Timecode::getEasyTimecode(GenTime(frames, KdenliveSettings::project_fps()), KdenliveSettings::project_fps()));
+    setData(0, DurationRole, Timecode::getEasyTimecode(GenTime(frames, KdenliveSettings::project_fps()), KdenliveSettings::project_fps()));
 }
 
 void ProjectItem::setProperties(QMap <QString, QString> props)
@@ -164,17 +151,6 @@ void ProjectItem::clearProperty(const QString &key)
     m_clip->clearProperty(key);
 }
 
-const QString ProjectItem::groupName() const
-{
-    return m_groupname;
-}
-
-void ProjectItem::setGroupName(const QString name)
-{
-    m_groupname = name;
-    setText(1, name);
-}
-
 DocClipBase *ProjectItem::referencedClip()
 {
     return m_clip;
@@ -183,6 +159,7 @@ DocClipBase *ProjectItem::referencedClip()
 void ProjectItem::slotSetToolTip()
 {
     QString tip = "<b>";
+    if (m_clip->isPlaceHolder()) tip.append(i18n("Missing") + " | ");
     switch (m_clipType) {
     case AUDIO:
         tip.append(i18n("Audio clip") + "</b><br />" + clipUrl().path());
@@ -217,7 +194,7 @@ void ProjectItem::slotSetToolTip()
         break;
     }
 
-    setToolTip(1, tip);
+    setToolTip(0, tip);
 }
 
 
@@ -227,7 +204,7 @@ void ProjectItem::setProperties(const QMap < QString, QString > &attributes, con
     //setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled);
     if (attributes.contains("duration")) {
         GenTime duration = GenTime(attributes.value("duration").toInt(), KdenliveSettings::project_fps());
-        setData(1, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
+        setData(0, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
         m_clip->setDuration(duration);
     } else  {
         // No duration known, use an arbitrary one until it is.
@@ -249,15 +226,14 @@ void ProjectItem::setProperties(const QMap < QString, QString > &attributes, con
     }
     m_clip->setProperties(attributes);
     m_clip->setMetadata(metadata);
-    if ((m_clipType == AV || m_clipType == AUDIO) && KdenliveSettings::audiothumbnails()) m_clip->askForAudioThumbs();
 
     if (m_clip->description().isEmpty()) {
         if (metadata.contains("description")) {
             m_clip->setProperty("description", metadata.value("description"));
-            setText(2, m_clip->description());
+            setText(1, m_clip->description());
         } else if (metadata.contains("comment")) {
             m_clip->setProperty("description", metadata.value("comment"));
-            setText(2, m_clip->description());
+            setText(1, m_clip->description());
         }
     }
 }
