@@ -29,15 +29,22 @@
 #include <QItemDelegate>
 #include <QUndoStack>
 #include <QTimer>
+#include <QApplication>
 
 #include <KTreeWidgetSearchLine>
 #include <KUrl>
+#include <KIcon>
+
+#ifdef NEPOMUK
 #include <nepomuk/kratingpainter.h>
 #include <nepomuk/resource.h>
+#endif
 
 #include "definitions.h"
 #include "timecode.h"
 #include "kdenlivesettings.h"
+#include "folderprojectitem.h"
+#include "subprojectitem.h"
 
 namespace Mlt
 {
@@ -59,36 +66,39 @@ class ItemDelegate: public QItemDelegate
 public:
     ItemDelegate(QAbstractItemView* parent = 0): QItemDelegate(parent) {
     }
-    /*
-    static_cast<ProjectItem *>( index.internalPointer() );
 
-    void expand()
-    {
-      QWidget *w = new QWidget;
-      QVBoxLayout *layout = new QVBoxLayout;
-      layout->addWidget( new KColorButton(w));
-      w->setLayout( layout );
-      extendItem(w,
-    }
-    */
-    void drawFocus(QPainter *, const QStyleOptionViewItem &, const QRect &) const {
-    }
+    /*void drawFocus(QPainter *, const QStyleOptionViewItem &, const QRect &) const {
+    }*/
 
     void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const {
-        if (index.column() == 1) {
+        if (index.column() == 0 && !index.data(DurationRole).isNull()) {
             QRect r1 = option.rect;
             painter->save();
             if (option.state & (QStyle::State_Selected)) {
                 painter->setPen(option.palette.color(QPalette::HighlightedText));
                 painter->fillRect(r1, option.palette.highlight());
             }
+            QStyleOptionViewItemV2 opt = setOptions(index, option);
+            QPixmap pixmap = decoration(opt, index.data(Qt::DecorationRole));
+            if ((index.flags() & (Qt::ItemIsDragEnabled)) == false) {
+                KIcon icon("dialog-close");
+                QPainter p(&pixmap);
+                p.drawPixmap(1, 1, icon.pixmap(16, 16));
+                p.end();
+            }
+            QRect decorationRect = pixmap.rect(); //QRect(QPoint(0, 0), option.decorationSize).intersected(pixmap.rect());
+            const int textMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin) + 1;
+            decorationRect.moveTo(r1.topLeft() + QPoint(0, 1));
+            drawDecoration(painter, opt, decorationRect, pixmap);
+            int decoWidth = pixmap.width() + 2 * textMargin;
+
             QFont font = painter->font();
             font.setBold(true);
             painter->setFont(font);
             int mid = (int)((r1.height() / 2));
-            r1.adjust(2, 0, 0, -mid);
+            r1.adjust(decoWidth, 0, 0, -mid);
             QRect r2 = option.rect;
-            r2.adjust(2, mid, 0, 0);
+            r2.adjust(decoWidth, mid, 0, 0);
             painter->drawText(r1, Qt::AlignLeft | Qt::AlignBottom , index.data().toString());
             //painter->setPen(Qt::green);
             font.setBold(false);
@@ -96,10 +106,10 @@ public:
             QString subText = index.data(DurationRole).toString();
             int usage = index.data(UsageRole).toInt();
             if (usage != 0) subText.append(QString(" (%1)").arg(usage));
-            painter->setPen(option.palette.color(QPalette::Mid));
+            if (option.state & (QStyle::State_Selected)) painter->setPen(option.palette.color(QPalette::Mid));
             painter->drawText(r2, Qt::AlignLeft | Qt::AlignVCenter , subText);
             painter->restore();
-        } else if (index.column() == 3 && KdenliveSettings::activate_nepomuk()) {
+        } else if (index.column() == 2 && KdenliveSettings::activate_nepomuk()) {
             if (index.data().toString().isEmpty()) {
                 QItemDelegate::paint(painter, option, index);
                 return;
@@ -108,7 +118,9 @@ public:
             if (option.state & (QStyle::State_Selected)) {
                 painter->fillRect(r1, option.palette.highlight());
             }
+#ifdef NEPOMUK
             KRatingPainter::paintRating(painter, r1, Qt::AlignCenter, index.data().toInt());
+#endif
         } else {
             QItemDelegate::paint(painter, option, index);
         }
@@ -131,10 +143,18 @@ public:
     void setupMenu(QMenu *addMenu, QAction *defaultAction);
     void setupGeneratorMenu(QMenu *addMenu, QMenu *transcodeMenu);
     QString currentClipUrl() const;
+    KUrl::List getConditionalUrls(const QString &condition) const;
     void reloadClipThumbnails();
     QDomDocument generateTemplateXml(QString data, const QString &replaceString);
     void cleanup();
     void trashUnusedClips();
+    QList <DocClipBase*> documentClipList() const;
+    void addClipCut(const QString &id, int in, int out, const QString desc, bool newItem);
+    void removeClipCut(const QString &id, int in, int out);
+    void focusTree() const;
+    SubProjectItem *getSubItem(ProjectItem *clip, QPoint zone);
+    void doUpdateClipCut(const QString &id, const QPoint oldzone, const QPoint zone, const QString &comment);
+    void deleteProjectFolder(QMap <QString, QString> map);
 
 public slots:
     void setDocument(KdenliveDoc *doc);
@@ -145,7 +165,7 @@ public slots:
     void slotDeleteClip(const QString &clipId);
     void slotUpdateClip(const QString &id);
     void slotRefreshClipThumbnail(const QString &clipId, bool update = true);
-    void slotRefreshClipThumbnail(ProjectItem *item, bool update = true);
+    void slotRefreshClipThumbnail(QTreeWidgetItem *item, bool update = true);
     void slotRemoveInvalidClip(const QString &id, bool replace);
     void slotSelectClip(const QString &ix);
     void slotRemoveClip();
@@ -157,6 +177,8 @@ public slots:
     void slotReloadClip(const QString &id = QString());
     void slotAddColorClip();
     void regenerateTemplate(const QString &id);
+    void slotUpdateClipCut(QPoint p);
+    void slotAddClipCut(const QString &id, int in, int out);
 
 private:
     ProjectListView *m_listView;
@@ -169,14 +191,14 @@ private:
     QUndoStack *m_commandStack;
     void selectItemById(const QString &clipId);
     ProjectItem *getItemById(const QString &id);
-    ProjectItem *getFolderItemById(const QString &id);
+    QTreeWidgetItem *getAnyItemById(const QString &id);
+    FolderProjectItem *getFolderItemById(const QString &id);
     QAction *m_editAction;
     QAction *m_deleteAction;
     QAction *m_openAction;
     QAction *m_reloadAction;
     QMenu *m_transcodeAction;
     KdenliveDoc *m_doc;
-    ProjectItem *m_selectedItem;
     ItemDelegate *m_listViewDelegate;
     bool m_refreshed;
     QToolButton *m_addButton;
@@ -185,10 +207,12 @@ private:
     void requestClipInfo(const QDomElement xml, const QString id);
     QList <QString> m_thumbnailQueue;
     void requestClipThumbnail(const QString id);
-    void deleteProjectFolder(QMap <QString, QString> map);
     void editFolder(const QString folderName, const QString oldfolderName, const QString &clipId);
     QStringList getGroup() const;
     void regenerateTemplate(ProjectItem *clip);
+    void editClipSelection(QList<QTreeWidgetItem *> list);
+    void adjustTranscodeActions(ProjectItem *clip) const;
+    void updateButtons() const;
 
 private slots:
     void slotClipSelected();
@@ -207,15 +231,18 @@ private slots:
     //void slotShowMenu(const QPoint &pos);
 
 signals:
-    void clipSelected(DocClipBase *);
-    void getFileProperties(const QDomElement, const QString &, bool);
+    void clipSelected(DocClipBase *, QPoint zone = QPoint());
+    void getFileProperties(const QDomElement, const QString &, int pixHeight, bool);
     void receivedClipDuration(const QString &);
     void showClipProperties(DocClipBase *);
+    void showClipProperties(QList <DocClipBase *>, QMap<QString, QString> commonproperties);
     void projectModified();
     void loadingIsOver();
     void displayMessage(const QString, int progress);
     void clipNameChanged(const QString, const QString);
+    void clipNeedsReload(const QString&, bool);
     void refreshClip();
+    void deleteProjectClips(QStringList ids, QMap <QString, QString> folderids);
 };
 
 #endif
