@@ -20,6 +20,8 @@
 
 #include "projectlistview.h"
 #include "projectitem.h"
+#include "subprojectitem.h"
+#include "folderprojectitem.h"
 #include "kdenlivesettings.h"
 
 #include <KDebug>
@@ -41,37 +43,37 @@ ProjectListView::ProjectListView(QWidget *parent) :
     setDragEnabled(true);
     setAcceptDrops(true);
 
-    setColumnCount(4);
+
+    setColumnCount(3);
     QStringList headers;
-    headers << i18n("Thumbnail") << i18n("Filename") << i18n("Description") << i18n("Rating");
+    headers << i18n("Clip") << i18n("Description") << i18n("Rating");
     setHeaderLabels(headers);
-    sortByColumn(1, Qt::AscendingOrder);
 
     QHeaderView* headerView = header();
     headerView->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(headerView, SIGNAL(customContextMenuRequested(const QPoint&)),
             this, SLOT(configureColumns(const QPoint&)));
-
-    //connect(this, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)), this, SLOT(slotFocusOut(QTreeWidgetItem *, QTreeWidgetItem *)));
-
-    if (!KdenliveSettings::showdescriptioncolumn()) hideColumn(2);
-    if (!KdenliveSettings::showratingcolumn()) hideColumn(3);
-
+    headerView->setClickable(true);
+    headerView->setSortIndicatorShown(true);
+    headerView->setMovable(false);
+    sortByColumn(0, Qt::AscendingOrder);
     setSortingEnabled(true);
+
+    if (!KdenliveSettings::showdescriptioncolumn()) hideColumn(1);
+    if (!KdenliveSettings::showratingcolumn()) hideColumn(2);
 }
 
 ProjectListView::~ProjectListView()
 {
 }
 
-
 void ProjectListView::configureColumns(const QPoint& pos)
 {
     KMenu popup(this);
     popup.addTitle(i18nc("@title:menu", "Columns"));
 
     QHeaderView* headerView = header();
-    for (int i = 2; i < headerView->count(); ++i) {
+    for (int i = 1; i < headerView->count(); ++i) {
         const QString text = model()->headerData(i, Qt::Horizontal).toString();
         QAction* action = popup.addAction(text);
         action->setCheckable(true);
@@ -86,10 +88,10 @@ void ProjectListView::configureColumns(const QPoint& pos)
         // remember the changed column visibility in the settings
         const int columnIndex = activatedAction->data().toInt();
         switch (columnIndex) {
-        case 2:
+        case 1:
             KdenliveSettings::setShowdescriptioncolumn(show);
             break;
-        case 3:
+        case 2:
             KdenliveSettings::setShowratingcolumn(show);
             break;
         default:
@@ -114,19 +116,42 @@ void ProjectListView::contextMenuEvent(QContextMenuEvent * event)
 // virtual
 void ProjectListView::mouseDoubleClickEvent(QMouseEvent * event)
 {
-    ProjectItem *item = static_cast <ProjectItem *>(itemAt(event->pos()));
-    if (!item) {
+    QTreeWidgetItem *it = itemAt(event->pos());
+    if (!it) {
         emit addClip();
         return;
     }
-    if (!(item->flags() & Qt::ItemIsDragEnabled)) return;
-    if (item->isGroup()) {
-        if ((columnAt(event->pos().x()) == 1)) QTreeWidget::mouseDoubleClickEvent(event);
-    } else {
-        if ((columnAt(event->pos().x()) == 1) && (item->clipType() == SLIDESHOW || item->clipType() == TEXT || item->clipType() == COLOR)) QTreeWidget::mouseDoubleClickEvent(event);
-        else if ((columnAt(event->pos().x()) == 2)) QTreeWidget::mouseDoubleClickEvent(event);
-        else emit showProperties(item->referencedClip());
+    ProjectItem *item;
+    if (it->type() == PROJECTFOLDERTYPE) {
+        if ((columnAt(event->pos().x()) == 0)) QTreeWidget::mouseDoubleClickEvent(event);
+        return;
     }
+    if (it->type() == PROJECTSUBCLIPTYPE) {
+        // subitem
+        if ((columnAt(event->pos().x()) == 1)) {
+            QTreeWidget::mouseDoubleClickEvent(event);
+            return;
+        }
+        item = static_cast <ProjectItem *>(it->parent());
+    } else item = static_cast <ProjectItem *>(it);
+
+    if (!(item->flags() & Qt::ItemIsDragEnabled)) return;
+
+    int column = columnAt(event->pos().x());
+    if (column == 0 && (item->clipType() == SLIDESHOW || item->clipType() == TEXT || item->clipType() == COLOR)) {
+        QPixmap pix = qVariantValue<QPixmap>(it->data(0, Qt::DecorationRole));
+        int offset = pix.width() + indentation();
+        if (item->parent()) offset += indentation();
+        if ((pix.isNull() || offset < event->pos().x())) {
+            QTreeWidget::mouseDoubleClickEvent(event);
+            return;
+        }
+    }
+    if ((column == 1) && it->type() != PROJECTSUBCLIPTYPE) {
+        QTreeWidget::mouseDoubleClickEvent(event);
+        return;
+    }
+    emit showProperties(item->referencedClip());
 }
 
 // virtual
@@ -141,50 +166,44 @@ void ProjectListView::dragEnterEvent(QDragEnterEvent *event)
 // virtual
 void ProjectListView::dropEvent(QDropEvent *event)
 {
-    kDebug() << "////////////////  DROPPED EVENT";
+    FolderProjectItem *item = NULL;
+    QTreeWidgetItem *it = itemAt(event->pos());
+    while (it && it->type() != PROJECTFOLDERTYPE) {
+        it = it->parent();
+    }
+    if (it) item = static_cast <FolderProjectItem *>(it);
     if (event->mimeData()->hasUrls()) {
-        ProjectItem *item = static_cast <ProjectItem *>(itemAt(event->pos()));
         QString groupName;
         QString groupId;
         if (item) {
-            if (item->parent()) item = static_cast <ProjectItem *>(item->parent());
-            if (item->isGroup()) {
-                groupName = item->groupName();
-                groupId = item->clipId();
-            }
+            groupName = item->groupName();
+            groupId = item->clipId();
         }
         emit addClip(event->mimeData()->urls(), groupName, groupId);
         event->setDropAction(Qt::CopyAction);
         event->accept();
         return;
     } else if (event->mimeData()->hasFormat("kdenlive/producerslist")) {
-        ProjectItem *item = static_cast <ProjectItem *>(itemAt(event->pos()));
         if (item) {
-            if (item->parent()) item = static_cast <ProjectItem *>(item->parent());
-            if (item->isGroup()) {
-                //emit addClip(event->mimeData->text());
-                kDebug() << "////////////////  DROPPED RIGHT 1 ";
-                const QList <QTreeWidgetItem *> list = selectedItems();
-                ProjectItem *clone;
-                QString parentId = item->clipId();
-                foreach(QTreeWidgetItem *it, list) {
-                    // TODO allow dragging of folders ?
-                    if (!((ProjectItem *) it)->isGroup()/* && ((ProjectItem *) it)->clipId() < 10000*/) {
-                        if (it->parent()) clone = (ProjectItem*) it->parent()->takeChild(it->parent()->indexOfChild(it));
-                        else clone = (ProjectItem*) takeTopLevelItem(indexOfTopLevelItem(it));
-                        if (clone) {
-                            item->addChild(clone);
-                            QMap <QString, QString> props;
-                            props.insert("groupname", item->groupName());
-                            props.insert("groupid", parentId);
-                            clone->setProperties(props);
-                        }
+            //emit addClip(event->mimeData->text());
+            const QList <QTreeWidgetItem *> list = selectedItems();
+            ProjectItem *clone;
+            QString parentId = item->clipId();
+            foreach(QTreeWidgetItem *it, list) {
+                // TODO allow dragging of folders ?
+                if (it->type() == PROJECTCLIPTYPE) {
+                    if (it->parent()) clone = (ProjectItem*) it->parent()->takeChild(it->parent()->indexOfChild(it));
+                    else clone = (ProjectItem*) takeTopLevelItem(indexOfTopLevelItem(it));
+                    if (clone) {
+                        item->addChild(clone);
+                        QMap <QString, QString> props;
+                        props.insert("groupname", item->groupName());
+                        props.insert("groupid", parentId);
+                        clone->setProperties(props);
                     }
-                }
-            } else item = NULL;
-        }
-        if (!item) {
-            kDebug() << "////////////////  DROPPED ON EMPTY ZONE";
+                } else item = NULL;
+            }
+        } else {
             // item dropped in empty zone, move it to top level
             const QList <QTreeWidgetItem *> list = selectedItems();
             ProjectItem *clone;
@@ -201,6 +220,10 @@ void ProjectListView::dropEvent(QDropEvent *event)
                 }
             }
         }
+        emit projectModified();
+    } else if (event->mimeData()->hasFormat("kdenlive/clip")) {
+        QStringList list = QString(event->mimeData()->data("kdenlive/clip")).split(';');
+        emit addClipCut(list.at(0), list.at(1).toInt(), list.at(2).toInt());
     }
     event->acceptProposedAction();
 }
@@ -235,21 +258,44 @@ void ProjectListView::mouseMoveEvent(QMouseEvent *event)
             < QApplication::startDragDistance())
         return;
 
-    {
-        ProjectItem *clickItem = static_cast <ProjectItem *>(itemAt(m_DragStartPosition));
+    QTreeWidgetItem *it = itemAt(m_DragStartPosition);
+    if (!it) return;
+    if (it->type() == PROJECTSUBCLIPTYPE) {
+        // subitem
+        SubProjectItem *clickItem = static_cast <SubProjectItem *>(it);
         if (clickItem && (clickItem->flags() & Qt::ItemIsDragEnabled)) {
+            ProjectItem *clip = static_cast <ProjectItem *>(it->parent());
+            QDrag *drag = new QDrag(this);
+            QMimeData *mimeData = new QMimeData;
+
+            QStringList list;
+            list.append(clip->clipId());
+            QPoint p = clickItem->zone();
+            list.append(QString::number(p.x()));
+            list.append(QString::number(p.y()));
+            QByteArray data;
+            data.append(list.join(";").toUtf8());
+            mimeData->setData("kdenlive/clip", data);
+            drag->setMimeData(mimeData);
+            drag->setPixmap(clickItem->data(0, Qt::DecorationRole).value<QPixmap>());
+            drag->setHotSpot(QPoint(0, 50));
+            drag->exec();
+        }
+    } else {
+        if (it && (it->flags() & Qt::ItemIsDragEnabled)) {
             QDrag *drag = new QDrag(this);
             QMimeData *mimeData = new QMimeData;
             const QList <QTreeWidgetItem *> list = selectedItems();
             QStringList ids;
             foreach(const QTreeWidgetItem *item, list) {
-                const ProjectItem *clip = static_cast <const ProjectItem *>(item);
-                if (!clip->isGroup()) ids.append(clip->clipId());
-                else {
+                if (item->type() == PROJECTFOLDERTYPE) {
                     const int children = item->childCount();
                     for (int i = 0; i < children; i++) {
                         ids.append(static_cast <ProjectItem *>(item->child(i))->clipId());
                     }
+                } else {
+                    const ProjectItem *clip = static_cast <const ProjectItem *>(item);
+                    ids.append(clip->clipId());
                 }
             }
             if (ids.isEmpty()) return;
@@ -259,7 +305,7 @@ void ProjectListView::mouseMoveEvent(QMouseEvent *event)
             //mimeData->setText(ids.join(";")); //doc.toString());
             //mimeData->setImageData(image);
             drag->setMimeData(mimeData);
-            drag->setPixmap(clickItem->icon(0).pixmap(iconSize()));
+            drag->setPixmap(it->data(0, Qt::DecorationRole).value<QPixmap>());
             drag->setHotSpot(QPoint(0, 50));
             drag->exec();
         }
@@ -286,6 +332,7 @@ QStringList ProjectListView::mimeTypes() const
     qstrList.append("text/uri-list");
     qstrList.append("text/plain");
     qstrList.append("kdenlive/producerslist");
+    qstrList.append("kdenlive/clip");
     return qstrList;
 }
 
