@@ -66,6 +66,8 @@ signals:
     void showProperties(DocClipBase *);
     void focusMonitor();
     void pauseMonitor();
+    void addClipCut(const QString&, int, int);
+    void projectModified();
 };
 
 #endif
