@@ -21,6 +21,8 @@
 #include "kdenlivesettings.h"
 #include "profilesdialog.h"
 #include "docclipbase.h"
+#include "titlewidget.h"
+#include "effectslist.h"
 
 #include <KStandardDirs>
 #include <KMessageBox>
@@ -31,11 +33,13 @@
 #include <QDir>
 #include <kmessagebox.h>
 
-ProjectSettings::ProjectSettings(ClipManager *manager, int videotracks, int audiotracks, const QString projectPath, bool readOnlyTracks, bool savedProject, QWidget * parent) :
-        QDialog(parent), m_savedProject(savedProject), m_clipManager(manager), m_deleteUnused(false)
+ProjectSettings::ProjectSettings(ProjectList *projectlist, QStringList lumas, int videotracks, int audiotracks, const QString projectPath, bool readOnlyTracks, bool savedProject, QWidget * parent) :
+        QDialog(parent), m_savedProject(savedProject), m_projectList(projectlist), m_lumas(lumas)
 {
     setupUi(this);
 
+    list_search->setListWidget(files_list);
+
     QMap <QString, QString> profilesInfo = ProfilesDialog::getProfilesInfo();
     QMapIterator<QString, QString> i(profilesInfo);
     while (i.hasNext()) {
@@ -64,7 +68,7 @@ ProjectSettings::ProjectSettings(ClipManager *manager, int videotracks, int audi
         audio_tracks->setEnabled(false);
     }
     slotUpdateDisplay();
-    if (manager != NULL) {
+    if (m_projectList != NULL) {
         slotUpdateFiles();
         connect(clear_cache, SIGNAL(clicked()), this, SLOT(slotClearCache()));
         connect(delete_unused, SIGNAL(clicked()), this, SLOT(slotDeleteUnused()));
@@ -76,26 +80,34 @@ ProjectSettings::ProjectSettings(ClipManager *manager, int videotracks, int audi
 void ProjectSettings::slotDeleteUnused()
 {
     QStringList toDelete;
-    QList <DocClipBase*> list = m_clipManager->documentClipList();
+    QList <DocClipBase*> list = m_projectList->documentClipList();
     for (int i = 0; i < list.count(); i++) {
         DocClipBase *clip = list.at(i);
-        if (clip->numReferences() == 0) {
+        if (clip->numReferences() == 0 && clip->clipType() != SLIDESHOW) {
             KUrl url = clip->fileURL();
-            if (!url.isEmpty()) toDelete << url.path();
+            if (!url.isEmpty() && !toDelete.contains(url.path())) toDelete << url.path();
         }
     }
+
+    // make sure our urls are not used in another clip
+    for (int i = 0; i < list.count(); i++) {
+        DocClipBase *clip = list.at(i);
+        if (clip->numReferences() > 0) {
+            KUrl url = clip->fileURL();
+            if (!url.isEmpty() && toDelete.contains(url.path())) toDelete.removeAll(url.path());
+        }
+    }
+
     if (toDelete.count() == 0) {
-        KMessageBox::sorry(this, i18n("No clip to delete"));
+        // No physical url to delete, we only remove unused clips from project (color clips for example have no physical url)
+        if (KMessageBox::warningContinueCancel(this, i18n("This will remove all unused clips from your project."), i18n("Clean up project")) == KMessageBox::Cancel) return;
+        m_projectList->cleanup();
+        slotUpdateFiles();
         return;
     }
     if (KMessageBox::warningYesNoList(this, i18n("This will remove the following files from your hard drive.\nThis action cannot be undone, only use if you know what you are doing.\nAre you sure you want to continue?"), toDelete, i18n("Delete unused clips")) != KMessageBox::Yes) return;
-    m_deleteUnused = true;
-    delete_unused->setEnabled(false);
-}
-
-bool ProjectSettings::deleteUnused() const
-{
-    return m_deleteUnused;
+    m_projectList->trashUnusedClips();
+    slotUpdateFiles();
 }
 
 void ProjectSettings::slotClearCache()
@@ -119,10 +131,33 @@ void ProjectSettings::slotUpdateFiles(bool cacheOnly)
     int used = 0;
     KIO::filesize_t usedSize = 0;
     KIO::filesize_t unUsedSize = 0;
-    QList <DocClipBase*> list = m_clipManager->documentClipList();
+    QList <DocClipBase*> list = m_projectList->documentClipList();
+    files_list->clear();
 
+    // List all files that are used in the project. That also means:
+    // images included in slideshow and titles, files in playlist clips
+    // TODO: images used in luma transitions, files used for LADSPA effects?
+
+    QStringList allFiles;
+    QStringList allFonts;
+    allFiles << m_lumas;
     for (int i = 0; i < list.count(); i++) {
         DocClipBase *clip = list.at(i);
+        if (clip->clipType() == SLIDESHOW) {
+            // special case, list all images
+            QStringList files = extractSlideshowUrls(clip->fileURL());
+            allFiles << files;
+        } else if (!clip->fileURL().isEmpty()) allFiles.append(clip->fileURL().path());
+        if (clip->clipType() == TEXT) {
+            QStringList images = TitleWidget::extractImageList(clip->getProperty("xmldata"));
+            QStringList fonts = TitleWidget::extractFontList(clip->getProperty("xmldata"));
+            allFiles << images;
+            allFonts << fonts;
+        } else if (clip->clipType() == PLAYLIST) {
+            QStringList files = extractPlaylistUrls(clip->fileURL().path());
+            allFiles << files;
+        }
+
         if (clip->numReferences() == 0) {
             unused++;
             unUsedSize += clip->fileSize();
@@ -131,11 +166,18 @@ void ProjectSettings::slotUpdateFiles(bool cacheOnly)
             usedSize += clip->fileSize();
         }
     }
+#if QT_VERSION >= 0x040500
+    allFiles.removeDuplicates();
+    allFonts.removeDuplicates();
+#endif
+    files_count->setText(QString::number(allFiles.count()));
+    files_list->addItems(allFiles);
+    fonts_list->addItems(allFonts);
     used_count->setText(QString::number(used));
     used_size->setText(KIO::convertSize(usedSize));
     unused_count->setText(QString::number(unused));
     unused_size->setText(KIO::convertSize(unUsedSize));
-    if (!m_deleteUnused) delete_unused->setEnabled(unused > 0);
+    delete_unused->setEnabled(unused > 0);
 }
 
 void ProjectSettings::accept()
@@ -194,6 +236,73 @@ bool ProjectSettings::enableAudioThumbs() const
     return audio_thumbs->isChecked();
 }
 
+//static
+QStringList ProjectSettings::extractPlaylistUrls(QString path)
+{
+    QStringList urls;
+    QDomDocument doc;
+    QFile file(path);
+    if (!file.open(QIODevice::ReadOnly))
+        return urls;
+    if (!doc.setContent(&file)) {
+        file.close();
+        return urls;
+    }
+    file.close();
+    QString root = doc.documentElement().attribute("root");
+    if (!root.isEmpty() && !root.endsWith('/')) root.append('/');
+    QDomNodeList files = doc.elementsByTagName("producer");
+    for (int i = 0; i < files.count(); i++) {
+        QDomElement e = files.at(i).toElement();
+        QString type = EffectsList::property(e, "mlt_service");
+        if (type != "colour") {
+            QString url = EffectsList::property(e, "resource");
+            if (!url.isEmpty()) {
+                if (!url.startsWith('/')) url.prepend(root);
+                if (url.section('.', 0, -2).endsWith("/.all")) {
+                    // slideshow clip, extract image urls
+                    urls << extractSlideshowUrls(KUrl(url));
+                } else urls << url;
+                if (url.endsWith(".mlt") || url.endsWith(".kdenlive")) {
+                    //TODO: Do something to avoid infinite loops if 2 files reference themselves...
+                    urls << extractPlaylistUrls(url);
+                }
+            }
+        }
+    }
+
+    // luma files for transitions
+    files = doc.elementsByTagName("transition");
+    for (int i = 0; i < files.count(); i++) {
+        QDomElement e = files.at(i).toElement();
+        QString url = EffectsList::property(e, "luma");
+        if (!url.isEmpty()) {
+            if (!url.startsWith('/')) url.prepend(root);
+            urls << url;
+        }
+    }
+
+    return urls;
+}
+
+
+//static
+QStringList ProjectSettings::extractSlideshowUrls(KUrl url)
+{
+    QStringList urls;
+    QString path = url.directory(KUrl::AppendTrailingSlash);
+    QString ext = url.path().section('.', -1);
+    QDir dir(path);
+    QStringList filters;
+    filters << "*." + ext;
+    dir.setNameFilters(filters);
+    QStringList result = dir.entryList(QDir::Files);
+    for (int j = 0; j < result.count(); j++) {
+        urls.append(path + result.at(j));
+    }
+    return urls;
+}
+
 #include "projectsettings.moc"
 
 
