@@ -31,6 +31,7 @@
 #include <KIO/NetAccess>
 #include <KFileItem>
 #include <KMessageBox>
+#include <KApplication>
 
 #if KDE_IS_VERSION(4,2,0)
 #include <KDiskFreeSpaceInfo>
@@ -254,6 +255,7 @@ QPixmap RecMonitor::mergeSideBySide(const QPixmap& pix, const QString txt)
     res.fill(Qt::transparent);
     p.begin(&res);
     p.drawPixmap(0, 0, pix);
+    p.setPen(kapp->palette().text().color());
     p.drawText(QRect(pixWidth + 8, 0, strWidth, strHeight), 0, txt);
     p.end();
     return res;
@@ -279,7 +281,7 @@ void RecMonitor::slotDisconnect()
         m_didCapture = false;
         slotStartCapture(false);
         m_discAction->setIcon(KIcon("network-disconnect"));
-        m_discAction->setText(i18n("Disonnect"));
+        m_discAction->setText(i18n("Disconnect"));
         m_recAction->setEnabled(true);
         m_stopAction->setEnabled(true);
         m_playAction->setEnabled(true);
@@ -493,6 +495,7 @@ void RecMonitor::slotRecord()
                 }
                 break;
             }
+            if (KdenliveSettings::rmd_hide_mouse()) m_captureArgs << "--no-cursor";
             m_isCapturing = true;
             if (KdenliveSettings::rmd_capture_audio()) {
                 m_captureArgs << "-freq" << KdenliveSettings::rmd_freq();
@@ -510,6 +513,8 @@ void RecMonitor::slotRecord()
             } else m_captureArgs << "--no-sound";
 
             if (KdenliveSettings::rmd_fullshots()) m_captureArgs << "--full-shots";
+            m_captureArgs << "--v_bitrate" << QString::number(KdenliveSettings::rmd_bitrate());
+            m_captureArgs << "--v_quality" << QString::number(KdenliveSettings::rmd_quality());
             m_captureArgs << "-workdir" << KdenliveSettings::currenttmpfolder();
             m_captureArgs << "-fps" << QString::number(KdenliveSettings::rmd_fps()) << "-o" << m_captureFile.path();
             m_captureProcess->start(KdenliveSettings::rmd_path(), m_captureArgs);
