@@ -21,6 +21,8 @@
 #ifndef RECMONITOR_H
 #define RECMONITOR_H
 
+#include "ui_recmonitor_ui.h"
+
 #include <QToolBar>
 #include <QTimer>
 #include <QProcess>
@@ -30,10 +32,13 @@
 #include <KAction>
 #include <KRestrictedLine>
 #include <KDateTime>
+#include <kdeversion.h>
 
-#include "ui_recmonitor_ui.h"
+#if KDE_IS_VERSION(4,2,0)
+#include <kcapacitybar.h>
+#endif
 
-class RecMonitor : public QWidget
+class RecMonitor : public QWidget, public Ui::RecMonitor_UI
 {
     Q_OBJECT
 
@@ -49,10 +54,15 @@ protected:
     virtual void mousePressEvent(QMouseEvent * event);
 
 private:
-    Ui::RecMonitor_UI m_ui;
     QString m_name;
     bool m_isActive;
     KDateTime m_captureTime;
+    QLabel m_dvinfo;
+
+#if KDE_IS_VERSION(4,2,0)
+    KCapacityBar *m_freeSpace;
+    QTimer m_spaceTimer;
+#endif
 
     KUrl m_captureFile;
     KIcon m_playIcon;
@@ -87,6 +97,8 @@ private slots:
     void slotDisconnect();
     //void slotStartGrab(const QRect &rect);
     void slotConfigure();
+    void slotReadDvgrabInfo();
+    void slotUpdateFreeSpace();
 
 public slots:
     void refreshRecMonitor(bool visible);
