@@ -108,7 +108,7 @@ public:
     void setRenderStatus(const QString &dest, int status, const QString &error);
     void setDocumentPath(const QString path);
     void reloadProfiles();
-    void setRenderProfile(const QString &dest, const QString &name, const QString &url);
+    void setRenderProfile(const QString &dest, const QString &group, const QString &name, const QString &url);
     int waitingJobsCount() const;
     QString getFreeScriptName(const QString &prefix = QString());
     bool startWaitingRenderJobs();
@@ -120,6 +120,7 @@ private slots:
     void slotUpdateButtons(KUrl url);
     void slotUpdateButtons();
     void refreshView();
+    void refreshCategory();
     void refreshParams();
     void slotSaveProfile();
     void slotEditProfile();
@@ -140,6 +141,8 @@ private slots:
     void slotHideLog();
     void slotPrepareExport(bool scriptExport = false);
     void slotPlayRendering(QTreeWidgetItem *item, int);
+    void slotStartCurrentJob();
+    void slotCopyToFavorites();
 
 private:
     Ui::RenderWidget_UI m_view;
@@ -154,13 +157,17 @@ private:
     void updateButtons();
     KUrl filenameWithExtension(KUrl url, QString extension);
     void checkRenderStatus();
+    void startRendering(QTreeWidgetItem *item);
+    void saveProfile(QDomElement newprofile);
+    QList <QListWidgetItem *> m_renderItems;
+    QList <QListWidgetItem *> m_renderCategory;
 
 signals:
     void abortProcess(const QString &url);
     void openDvdWizard(const QString &url, const QString &profile);
     /** Send the infos about rendering that will be saved in the document:
     (profile destination, profile name and url of rendered file */
-    void selectedRenderProfile(const QString &, const QString &, const QString &);
+    void selectedRenderProfile(const QString &, const QString &, const QString &, const QString &);
     void prepareRenderingData(bool scriptExport, bool zoneOnly, const QString &chapterFile);
     void shutdown();
 };
