@@ -36,10 +36,12 @@ public:
     Transform() {
         scalex = 1.0;
         scaley = 1.0;
-        rotate = 0.0;
+        rotatex = 0.0;
+        rotatey = 0.0;
+        rotatez = 0.0;
     }
     double scalex, scaley;
-    double rotate;
+    double rotatex, rotatey, rotatez;
 };
 
 class TitleWidget : public QDialog , public Ui::TitleWidget_UI
@@ -62,6 +64,16 @@ public:
      * The path "/titles/" is appended to projectUrl to locate the actual directory that contains the title pngs. */
     static QStringList getFreeTitleInfo(const KUrl &projectUrl, bool isClone = false);
 
+    /** \brief Return a list af all images included in a title
+     * \param xml The xml data for title
+    */
+    static QStringList extractImageList(QString xml);
+
+    /** \brief Return a list af all fonts included in a title
+     * \param xml The xml data for title
+    */
+    static QStringList extractFontList(QString xml);
+
     /** \brief Build a filename from a projectUrl and a titleName
      * \param projectUrl Url to directory of project.
      * \param titleName Name of title, on the form "titleXXX"
@@ -102,6 +114,10 @@ private:
     QAction *m_buttonLoad;
 
     QAction *m_unicodeAction;
+    QAction *m_zUp;
+    QAction *m_zDown;
+    QAction *m_zTop;
+    QAction *m_zBottom;
 
     /** \brief Dialog for entering unicode in text fields */
     UnicodeDialog *m_unicodeDialog;
@@ -152,6 +168,17 @@ private:
     /** \brief Remove the "start" and "end" info text from animation viewports */
     void deleteAnimInfoText();
 
+    qreal maxZIndex();
+    /**
+     * \brief Get the minimum/maximum z index value of items.
+     * \param maxBound true: Use maximum z index. false: Use minimum
+     * \param intersectingOnly Only considers the items intersecting with
+     * the currently selected item if true.
+     */
+    qreal zIndexBounds(bool maxBound, bool intersectingOnly);
+
+    void itemRotate(qreal val, int axis);
+
 public slots:
     void slotNewText(QGraphicsTextItem *tt);
     void slotNewRect(QGraphicsRectItem *rect);
@@ -161,7 +188,9 @@ public slots:
     void setupViewports();
     void zIndexChanged(int);
     void itemScaled(int);
-    void itemRotate(int);
+    void itemRotateX(qreal);
+    void itemRotateY(qreal);
+    void itemRotateZ(qreal);
     void saveTitle(KUrl url = KUrl());
     void loadTitle(KUrl url = KUrl());
 
@@ -248,6 +277,19 @@ private slots:
 
     /** \brief Called when accepted, stores the user selections for next time use */
     void slotAccepted();
+
+    void slotFontText(const QString& s);
+
+    void slotAddEffect(int ix);
+    void slotEditBlur(int ix);
+    void slotEditShadow();
+    void slotEditTypewriter(int ix);
+
+    /** \brief Changes the z index of objects. */
+    void slotZIndexUp();
+    void slotZIndexDown();
+    void slotZIndexTop();
+    void slotZIndexBottom();
 };
 
 
