@@ -103,10 +103,10 @@ TrackView::TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent) :
     connect(m_trackview->verticalScrollBar(), SIGNAL(valueChanged(int)), headers_area->verticalScrollBar(), SLOT(setValue(int)));
     connect(m_trackview, SIGNAL(trackHeightChanged()), this, SLOT(slotRebuildTrackHeaders()));
     connect(m_trackview, SIGNAL(tracksChanged()), this, SLOT(slotReloadTracks()));
+    connect(m_trackview, SIGNAL(updateTrackHeaders()), this, SLOT(slotRepaintTracks()));
 
     parseDocument(m_doc->toXml());
-    int error = m_doc->setSceneList();
-    if (error == -1) *ok = false;
+    if (m_doc->setSceneList() == -1) *ok = false;
     else *ok = true;
     connect(m_trackview, SIGNAL(cursorMoved(int, int)), m_ruler, SLOT(slotCursorMoved(int, int)));
     connect(m_trackview->horizontalScrollBar(), SIGNAL(valueChanged(int)), m_ruler, SLOT(slotMoveRuler(int)));
@@ -123,6 +123,18 @@ TrackView::~TrackView()
     delete m_trackview;
 }
 
+//virtual
+void TrackView::keyPressEvent(QKeyEvent * event)
+{
+    if (event->key() == Qt::Key_Up) {
+        m_trackview->slotTrackUp();
+        event->accept();
+    } else if (event->key() == Qt::Key_Down) {
+        m_trackview->slotTrackDown();
+        event->accept();
+    } else QWidget::keyPressEvent(event);
+}
+
 int TrackView::duration() const
 {
     return m_trackview->duration();
@@ -271,15 +283,36 @@ void TrackView::parseDocument(QDomDocument doc)
                     transitionAdd = false;
                     //kDebug() << "//  TRANSITRION " << i << " IS NOT VALID (INTERN ADDED)";
                     //break;
-                } else if (paramName == "a_track") a_track = p.text().toInt();
-                else if (paramName == "b_track") b_track = p.text().toInt();
-                else if (paramName == "mlt_service") mlt_service = p.text();
+                } else if (paramName == "a_track") {
+                    a_track = qMax(0, p.text().toInt());
+                    a_track = qMin(m_projectTracks - 1, a_track);
+                    if (a_track != p.text().toInt()) {
+                        // the transition track was out of bounds
+                        m_documentErrors.append(i18n("Transition %1 had an invalid track: %2 > %3", e.attribute("id"), p.text().toInt(), a_track) + '\n');
+                        EffectsList::setProperty(e, "a_track", QString::number(a_track));
+                    }
+                } else if (paramName == "b_track") {
+                    b_track = qMax(0, p.text().toInt());
+                    b_track = qMin(m_projectTracks - 1, b_track);
+                    if (b_track != p.text().toInt()) {
+                        // the transition track was out of bounds
+                        m_documentErrors.append(i18n("Transition %1 had an invalid track: %2 > %3", e.attribute("id"), p.text().toInt(), b_track) + '\n');
+                        EffectsList::setProperty(e, "b_track", QString::number(b_track));
+                    }
+                } else if (paramName == "mlt_service") mlt_service = p.text();
                 else if (paramName == "kdenlive_id") transitionId = p.text();
                 else if (paramName == "geometry") mlt_geometry = p.text();
                 else if (paramName == "automatic" && p.text() == "1") isAutomatic = true;
                 else if (paramName == "force_track" && p.text() == "1") forceTrack = true;
             }
         }
+        if (a_track == b_track || b_track == 0) {
+            // invalid transition, remove it
+            m_documentErrors.append(i18n("Removed invalid transition: %1", e.attribute("id")) + '\n');
+            tractor.removeChild(transitions.item(i));
+            i--;
+            continue;
+        }
         if (transitionAdd || mlt_service != "mix") {
             // Transition should be added to the scene
             ItemInfo transitionInfo;
@@ -311,32 +344,32 @@ void TrackView::parseDocument(QDomDocument doc)
             QDomElement base = MainWindow::transitions.getEffectByTag(mlt_service, transitionId).cloneNode().toElement();
 
             for (int k = 0; k < transitionparams.count(); k++) {
-                p = transitionparams.item(k).toElement();
-                if (!p.isNull()) {
-                    QString paramName = p.attribute("name");
-                    QString paramValue = p.text();
+                    p = transitionparams.item(k).toElement();
+                    if (!p.isNull()) {
+                        QString paramName = p.attribute("name");
+                        QString paramValue = p.text();
 
-                    QDomNodeList params = base.elementsByTagName("parameter");
-                    if (paramName != "a_track" && paramName != "b_track") for (int i = 0; i < params.count(); i++) {
-                            QDomElement e = params.item(i).toElement();
-                            if (!e.isNull() && e.attribute("tag") == paramName) {
-                                if (e.attribute("type") == "double") {
-                                    QString factor = e.attribute("factor", "1");
-                                    if (factor != "1") {
-                                        double fact;
-                                        if (factor.startsWith('%')) {
-                                            fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
-                                        } else fact = factor.toDouble();
-                                        double val = paramValue.toDouble() * fact;
-                                        paramValue = QString::number(val);
+                        QDomNodeList params = base.elementsByTagName("parameter");
+                        if (paramName != "a_track" && paramName != "b_track") for (int i = 0; i < params.count(); i++) {
+                                QDomElement e = params.item(i).toElement();
+                                if (!e.isNull() && e.attribute("tag") == paramName) {
+                                    if (e.attribute("type") == "double") {
+                                        QString factor = e.attribute("factor", "1");
+                                        if (factor != "1") {
+                                            double fact;
+                                            if (factor.startsWith('%')) {
+                                                fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
+                                            } else fact = factor.toDouble();
+                                            double val = paramValue.toDouble() * fact;
+                                            paramValue = QString::number(val);
+                                        }
                                     }
+                                    e.setAttribute("value", paramValue);
+                                    break;
                                 }
-                                e.setAttribute("value", paramValue);
-                                break;
                             }
-                        }
+                    }
                 }
-            }
 
             /*QDomDocument doc;
             doc.appendChild(doc.importNode(base, true));
@@ -395,7 +428,7 @@ void TrackView::parseDocument(QDomDocument doc)
             ct++;
             backupFile = baseFile + "_backup" + QString::number(ct) + ".kdenlive";
         }
-        if (KIO::NetAccess::file_copy(m_doc->url(), KUrl(backupFile), this)) KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version.\n To make sure you don't loose data, a backup copy called: %1 was created.", backupFile));
+        if (KIO::NetAccess::file_copy(m_doc->url(), KUrl(backupFile), this)) KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version.\n To make sure you don't lose data, a backup copy called %1 was created.", backupFile));
         else KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version, it was not possible to create a backup copy.", backupFile));
     }
     //m_trackview->setCursorPos(cursorPos);
@@ -453,6 +486,18 @@ void TrackView::refresh()
     m_trackview->viewport()->update();
 }
 
+void TrackView::slotRepaintTracks()
+{
+    QLayoutItem *child;
+    for (int i = 0; i < headers_container->layout()->count(); i++) {
+        child = headers_container->layout()->itemAt(i);
+        if (child->widget() && child->widget()->height() > 5) {
+            HeaderTrack *head = static_cast <HeaderTrack *>(child->widget());
+            if (head) head->setSelectedIndex(m_trackview->selectedTrack());
+        }
+    }
+}
+
 void TrackView::slotReloadTracks()
 {
     slotRebuildTrackHeaders();
@@ -481,10 +526,11 @@ void TrackView::slotRebuildTrackHeaders()
         headers_container->layout()->addWidget(frame);
         TrackInfo info = list.at(max - i - 1);
         header = new HeaderTrack(i, info, height, headers_container);
+        header->setSelectedIndex(m_trackview->selectedTrack());
         connect(header, SIGNAL(switchTrackVideo(int)), m_trackview, SLOT(slotSwitchTrackVideo(int)));
         connect(header, SIGNAL(switchTrackAudio(int)), m_trackview, SLOT(slotSwitchTrackAudio(int)));
         connect(header, SIGNAL(switchTrackLock(int)), m_trackview, SLOT(slotSwitchTrackLock(int)));
-
+        connect(header, SIGNAL(selectTrack(int)), m_trackview, SLOT(slotSelectTrack(int)));
         connect(header, SIGNAL(deleteTrack(int)), this, SIGNAL(deleteTrack(int)));
         connect(header, SIGNAL(insertTrack(int)), this, SIGNAL(insertTrack(int)));
         connect(header, SIGNAL(changeTrack(int)), this, SIGNAL(changeTrack(int)));
@@ -588,7 +634,6 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                 if (locked) item->setItemLocked(true);
                 clip->addReference();
                 position += (out - in + 1);
-                kDebug() << "/////////\n\n\n" << "CLIP SPEED: " << speed << ", " << strobe << "\n\n\n/////////////////////";
                 if (speed != 1.0 || strobe > 1) {
                     QDomElement speedeffect = MainWindow::videoEffects.getEffectByTag(QString(), "speed").cloneNode().toElement();
                     EffectsList::setParameter(speedeffect, "speed", QString::number((int)(100 * speed + 0.5)));
@@ -600,12 +645,13 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                 // parse clip effects
                 QDomNodeList effects = elem.childNodes();
                 for (int ix = 0; ix < effects.count(); ix++) {
+                    bool disableeffect = false;
                     QDomElement effect = effects.at(ix).toElement();
                     if (effect.tagName() == "filter") {
                         // add effect to clip
                         QString effecttag;
                         QString effectid;
-                        QString effectindex;
+                        QString effectindex = QString::number(ix + 1);
                         QString ladspaEffectFile;
                         // Get effect tag & index
                         for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
@@ -615,8 +661,12 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                                 effecttag = effectparam.text();
                             } else if (effectparam.attribute("name") == "kdenlive_id") {
                                 effectid = effectparam.text();
+                            } else if (effectparam.attribute("name") == "disable" && effectparam.text().toInt() == 1) {
+                                // Fix effects index
+                                disableeffect = true;
                             } else if (effectparam.attribute("name") == "kdenlive_ix") {
-                                effectindex = effectparam.text();
+                                // Fix effects index
+                                effectparam.firstChild().setNodeValue(effectindex);
                             } else if (effectparam.attribute("name") == "src") {
                                 ladspaEffectFile = effectparam.text();
                                 if (!QFile::exists(ladspaEffectFile)) {
@@ -745,7 +795,15 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                                             if (factor.startsWith('%')) {
                                                 fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
                                             } else fact = factor.toDouble();
-                                            e.setAttribute("value", paramvalue.toDouble() * fact);
+                                            if (e.attribute("type") == "simplekeyframe") {
+                                                QStringList kfrs = paramvalue.split(";");
+                                                for (int l = 0; l < kfrs.count(); l++) {
+                                                    QString fr = kfrs.at(l).section("=", 0, 0);
+                                                    double val = kfrs.at(l).section("=", 1, 1).toDouble();
+                                                    kfrs[l] = fr + ":" + QString::number((int)(val * fact));
+                                                }
+                                                e.setAttribute("keyframes", kfrs.join(";"));
+                                            } else e.setAttribute("value", paramvalue.toDouble() * fact);
                                         } else e.setAttribute("value", paramvalue);
                                         break;
                                     }
@@ -760,8 +818,8 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                                 }
                                 currenteffect.setAttribute("src", ladspaEffectFile);
                             }
+                            if (disableeffect) currenteffect.setAttribute("disable", "1");
                             item->addEffect(currenteffect, false);
-                            item->effectsCounter();
                         }
                     }
                 }
