@@ -59,6 +59,9 @@ public:
     int inPoint() const;
     int fitZoom() const;
 
+protected:
+    virtual void keyPressEvent(QKeyEvent * event);
+
 public slots:
     void slotDeleteClip(const QString &clipId);
     void slotChangeZoom(int horizontal, int vertical = -1);
@@ -93,6 +96,7 @@ private slots:
     void slotVerticalZoomDown();
     void slotVerticalZoomUp();
     void slotRenameTrack(int ix);
+    void slotRepaintTracks();
 
 signals:
     void mousePosition(int);
