@@ -54,8 +54,8 @@ public:
     bool hasClip(const ClipItem * clip) const;
     bool belongsToClip(const ClipItem * clip) const;
     bool invertedTransition() const;
-    QString transitionName() const;
     QString transitionTag() const;
+    QStringList transitionInfo() const;
     OPERATIONTYPE operationMode(QPointF pos);
     //const QMap < QString, QString > transitionParameters() const;
     void setTransitionParameters(const QDomElement params);
@@ -72,6 +72,7 @@ public:
     bool isAutomatic() const;
     void setAutomatic(bool automatic);
     bool hasGeometry();
+    int defaultZValue() const;
 
 protected:
     virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value);
@@ -96,6 +97,10 @@ private:
 
     /** Return the transition type for a given name */
     TRANSITIONTYPE getTransitionForName(const QString & type);
+
+#if QT_VERSION >= 0x040600
+    QPropertyAnimation *m_startAnimation;
+#endif
 };
 
 #endif
